api
library
Classes
-
AccessSchema
-
-
AccountAchievementObjectiveSchema
-
-
AccountAchievementSchema
-
-
AccountDetails
-
-
AccountDetailsSchema
-
-
AccountLeaderboardSchema
-
-
AccountLeaderboardType
-
-
AccountLeaderboardTypeTypeTransformer
-
Transformation class that can encode an instance of AccountLeaderboardType to String,
and decode dynamic data back to AccountLeaderboardType.
-
AccountsApi
-
-
AccountStatus
-
-
AccountStatusTypeTransformer
-
Transformation class that can encode an instance of AccountStatus to String,
and decode dynamic data back to AccountStatus.
-
AchievementObjectiveSchema
-
-
AchievementResponseSchema
-
-
AchievementRewardsSchema
-
-
AchievementsApi
-
-
AchievementSchema
-
-
AchievementType
-
-
AchievementTypeTypeTransformer
-
Transformation class that can encode an instance of AchievementType to String,
and decode dynamic data back to AchievementType.
-
ActionType
-
-
ActionTypeTypeTransformer
-
Transformation class that can encode an instance of ActionType to String,
and decode dynamic data back to ActionType.
-
ActiveCharacterSchema
-
-
ActiveEventResponseSchema
-
-
ActiveEventSchema
-
-
AddAccountSchema
-
-
AddCharacterSchema
-
-
ApiClient
-
-
ApiKeyAuth
-
-
AssistantAnswerDataSchema
-
-
AssistantAnswerSchema
-
-
AssistantQuestionSchema
-
-
Authentication
-
-
BadgeResponseSchema
-
-
BadgesApi
-
-
BadgeSchema
-
-
BankExtensionSchema
-
-
BankExtensionTransactionResponseSchema
-
-
BankExtensionTransactionSchema
-
-
BankGoldTransactionResponseSchema
-
-
BankGoldTransactionSchema
-
-
BankItemTransactionResponseSchema
-
-
BankItemTransactionSchema
-
-
BankResponseSchema
-
-
BankSchema
-
-
BuyCustomDesignRequestSchema
-
-
BuySkinRequestSchema
-
-
BuySkinResponseDataSchema
-
-
BuySkinResponseSchema
-
-
ChangeEmailSchema
-
-
ChangePasswordSchema
-
-
ChangeSkinCharacterDataSchema
-
-
ChangeSkinCharacterSchema
-
-
ChangeSkinResponseSchema
-
-
CharacterFightDataSchema
-
-
CharacterFightResponseSchema
-
-
CharacterFightSchema
-
-
CharacterLeaderboardSchema
-
-
CharacterLeaderboardType
-
-
CharacterLeaderboardTypeTypeTransformer
-
Transformation class that can encode an instance of CharacterLeaderboardType to String,
and decode dynamic data back to CharacterLeaderboardType.
-
CharacterMovementDataSchema
-
-
CharacterMovementResponseSchema
-
-
CharacterMultiFightResultSchema
-
-
CharacterResponseSchema
-
-
CharacterRestDataSchema
-
-
CharacterRestResponseSchema
-
-
CharactersApi
-
-
CharacterSchema
-
-
CharactersListSchema
-
-
CharacterStatsResponseSchema
-
-
CharacterStatsSchema
-
-
CharacterTransitionDataSchema
-
-
CharacterTransitionResponseSchema
-
-
CheckoutResponseSchema
-
-
CheckoutResponseWrapperSchema
-
-
ClaimPendingItemDataSchema
-
-
ClaimPendingItemResponseSchema
-
-
CombatResultSchema
-
-
CombatSimulationDataSchema
-
-
CombatSimulationRequestSchema
-
-
CombatSimulationResponseSchema
-
-
ConditionOperator
-
-
ConditionOperatorTypeTransformer
-
Transformation class that can encode an instance of ConditionOperator to String,
and decode dynamic data back to ConditionOperator.
-
ConditionSchema
-
-
CooldownSchema
-
-
CraftingSchema
-
-
CraftSchema
-
-
CraftSkill
-
-
CraftSkillTypeTransformer
-
Transformation class that can encode an instance of CraftSkill to String,
and decode dynamic data back to CraftSkill.
-
DataPageAccountAchievementSchema
-
-
DataPageAccountLeaderboardSchema
-
-
DataPageActiveCharacterSchema
-
-
DataPageCharacterLeaderboardSchema
-
-
DataPageGEOrderHistorySchema
-
-
DataPageGEOrderSchema
-
-
DataPageLogSchema
-
-
DataPagePendingItemSchema
-
-
-
DataPageSimpleItemSchema
-
-
DeleteCharacterSchema
-
-
DeleteItemResponseSchema
-
-
DeleteItemSchema
-
-
DepositWithdrawGoldSchema
-
-
DeserializationMessage
-
Primarily intended for use in an isolate.
-
DestinationSchema
-
-
DropRateSchema
-
-
DropSchema
-
-
EffectResponseSchema
-
-
EffectsApi
-
-
EffectSchema
-
-
EffectSubtype
-
-
EffectSubtypeTypeTransformer
-
Transformation class that can encode an instance of EffectSubtype to String,
and decode dynamic data back to EffectSubtype.
-
EffectType
-
-
EffectTypeTypeTransformer
-
Transformation class that can encode an instance of EffectType to String,
and decode dynamic data back to EffectType.
-
EquipmentItemSchema
-
-
EquipmentResponseSchema
-
-
EquipmentTransactionSchema
-
-
EquipSchema
-
-
ErrorResponseSchema
-
-
ErrorSchema
-
-
EventContentSchema
-
-
EventMapSchema
-
-
EventsApi
-
-
EventSchema
-
-
FakeCharacterSchema
-
-
FightRequestSchema
-
-
FightResult
-
-
FightResultTypeTransformer
-
Transformation class that can encode an instance of FightResult to String,
and decode dynamic data back to FightResult.
-
GameAssistantApi
-
-
GatheringSkill
-
-
GatheringSkillTypeTransformer
-
Transformation class that can encode an instance of GatheringSkill to String,
and decode dynamic data back to GatheringSkill.
-
GEBuyOrderCreationSchema
-
-
GEBuyOrderSchema
-
-
GECancelOrderSchema
-
-
GECreateOrderTransactionResponseSchema
-
-
GEFillBuyOrderSchema
-
-
GemShopCatalogDataSchema
-
-
GemShopCatalogResponseSchema
-
-
GemShopCustomDesignCatalogItemSchema
-
-
GemShopCustomDesignCatalogItemSchemaCategoryEnum
-
Custom design category.
-
GemShopCustomDesignCatalogItemSchemaCategoryEnumTypeTransformer
-
Transformation class that can encode an instance of GemShopCustomDesignCatalogItemSchemaCategoryEnum to String,
and decode dynamic data back to GemShopCustomDesignCatalogItemSchemaCategoryEnum.
-
GemShopCustomDesignPurchaseResponseDataSchema
-
-
GemShopCustomDesignPurchaseResponseSchema
-
-
GemShopSkinCatalogItemSchema
-
-
GemShopSpawnEventCatalogItemSchema
-
-
GemShopSubscriptionCatalogItemSchema
-
-
GemShopSubscriptionResponseDataSchema
-
-
GemShopSubscriptionResponseSchema
-
-
GemsShopApi
-
-
GemTransactionListResponseSchema
-
-
GemTransactionSchema
-
-
GEOrderCreatedSchema
-
-
GEOrderCreationSchema
-
-
GEOrderHistorySchema
-
-
GEOrderResponseSchema
-
-
GEOrderSchema
-
-
GEOrderTransactionSchema
-
-
GEOrderType
-
Type of Grand Exchange order.
-
GEOrderTypeTypeTransformer
-
Transformation class that can encode an instance of GEOrderType to String,
and decode dynamic data back to GEOrderType.
-
GETransactionListSchema
-
-
GETransactionResponseSchema
-
-
GETransactionSchema
-
-
GiveGoldDataSchema
-
-
GiveGoldResponseSchema
-
-
GiveGoldSchema
-
-
GiveItemDataSchema
-
-
GiveItemResponseSchema
-
-
GiveItemsSchema
-
-
GoldSchema
-
-
GrandExchangeApi
-
-
HttpBasicAuth
-
-
HttpBearerAuth
-
-
HTTPValidationError
-
-
InteractionSchema
-
-
InventorySlotSchema
-
-
ItemResponseSchema
-
-
ItemsApi
-
-
ItemSchema
-
-
ItemSlot
-
-
ItemSlotTypeTransformer
-
Transformation class that can encode an instance of ItemSlot to String,
and decode dynamic data back to ItemSlot.
-
ItemType
-
-
ItemTypeTypeTransformer
-
Transformation class that can encode an instance of ItemType to String,
and decode dynamic data back to ItemType.
-
LeaderboardApi
-
-
LocationInner
-
-
LogSchema
-
-
LogType
-
-
LogTypeTypeTransformer
-
Transformation class that can encode an instance of LogType to String,
and decode dynamic data back to LogType.
-
MapAccessType
-
-
MapAccessTypeTypeTransformer
-
Transformation class that can encode an instance of MapAccessType to String,
and decode dynamic data back to MapAccessType.
-
MapContentSchema
-
-
MapContentType
-
-
MapContentTypeTypeTransformer
-
Transformation class that can encode an instance of MapContentType to String,
and decode dynamic data back to MapContentType.
-
MapLayer
-
-
MapLayerTypeTransformer
-
Transformation class that can encode an instance of MapLayer to String,
and decode dynamic data back to MapLayer.
-
MapResponseSchema
-
-
MapsApi
-
-
MapSchema
-
-
MemberTokenSubscriptionResponseDataSchema
-
-
MemberTokenSubscriptionResponseSchema
-
-
MonsterResponseSchema
-
-
MonstersApi
-
-
MonsterSchema
-
-
MonsterType
-
-
MonsterTypeTypeTransformer
-
Transformation class that can encode an instance of MonsterType to String,
and decode dynamic data back to MonsterType.
-
MyAccountApi
-
-
MyAccountDetails
-
-
MyAccountDetailsSchema
-
-
MyCharactersApi
-
-
MyCharactersListSchema
-
-
NPCItemSchema
-
-
NpcItemTransactionSchema
-
-
NpcMerchantBuySchema
-
-
NpcMerchantTransactionResponseSchema
-
-
NpcMerchantTransactionSchema
-
-
NPCResponseSchema
-
-
NPCsApi
-
-
NPCSchema
-
-
NPCType
-
-
NPCTypeTypeTransformer
-
Transformation class that can encode an instance of NPCType to String,
and decode dynamic data back to NPCType.
-
OAuth
-
-
PasswordResetConfirmSchema
-
-
PasswordResetRequestSchema
-
-
PasswordResetResponseSchema
-
-
PendingItemSchema
-
-
PendingItemSource
-
Source types for pending items.
-
PendingItemSourceTypeTransformer
-
Transformation class that can encode an instance of PendingItemSource to String,
and decode dynamic data back to PendingItemSource.
-
PurchaseGemsRequestSchema
-
-
PurchaseGemsRequestSchemaQuantityEnum
-
Number of gems to purchase.
-
PurchaseGemsRequestSchemaQuantityEnumTypeTransformer
-
Transformation class that can encode an instance of PurchaseGemsRequestSchemaQuantityEnum to int,
and decode dynamic data back to PurchaseGemsRequestSchemaQuantityEnum.
-
PurchaseHistoryListResponseSchema
-
-
PurchaseHistorySchema
-
-
PurchaseType
-
Type of purchase in history.
-
PurchaseTypeTypeTransformer
-
Transformation class that can encode an instance of PurchaseType to String,
and decode dynamic data back to PurchaseType.
-
QueryParam
-
-
RaidDamageRewardSchema
-
-
RaidInstanceResult
-
-
RaidInstanceResultTypeTransformer
-
Transformation class that can encode an instance of RaidInstanceResult to String,
and decode dynamic data back to RaidInstanceResult.
-
RaidInstanceSchema
-
-
RaidLeaderboardEntrySchema
-
-
RaidRankRewardSchema
-
-
RaidResponseSchema
-
-
RaidRewardsSchema
-
-
RaidsApi
-
-
RaidScheduleSchema
-
-
RaidSchema
-
-
RaidStatus
-
-
RaidStatusTypeTransformer
-
Transformation class that can encode an instance of RaidStatus to String,
and decode dynamic data back to RaidStatus.
-
RaidWeekday
-
-
RaidWeekdayTypeTransformer
-
Transformation class that can encode an instance of RaidWeekday to String,
and decode dynamic data back to RaidWeekday.
-
RateLimitSchema
-
-
RateLimitScopeSchema
-
-
RateLimitsDataSchema
-
-
RateLimitsSchema
-
-
RateLimitWindowSchema
-
-
RecyclingDataSchema
-
-
RecyclingItemsSchema
-
-
RecyclingResponseSchema
-
-
RecyclingSchema
-
-
ResourceResponseSchema
-
-
ResourcesApi
-
-
ResourceSchema
-
-
ResponseSchema
-
-
RewardDataResponseSchema
-
-
RewardDataSchema
-
-
RewardItemSchema
-
-
RewardResponseSchema
-
-
RewardsSchema
-
-
RewardType
-
Type of season reward.
-
RewardTypeTypeTransformer
-
Transformation class that can encode an instance of RewardType to String,
and decode dynamic data back to RewardType.
-
SandboxApi
-
-
SandboxCharacterActionSchema
-
-
SandboxGiveGoldDataSchema
-
-
SandboxGiveGoldResponseSchema
-
-
SandboxGiveItemDataSchema
-
-
SandboxGiveItemResponseSchema
-
-
SandboxGiveItemSchema
-
-
SandboxGiveXPDataSchema
-
-
SandboxGiveXPResponseSchema
-
-
SandboxGiveXPSchema
-
-
SandboxResponseSchema
-
-
SandboxSchema
-
-
SandboxTeleportDataSchema
-
-
SandboxTeleportResponseSchema
-
-
SandboxTeleportSchema
-
-
SeasonRewardsApi
-
-
SeasonRewardSchema
-
-
SeasonSchema
-
-
ServerDetailsApi
-
-
SimpleEffectSchema
-
-
SimpleItemSchema
-
-
SimpleNPCItemSchema
-
-
SimulationApi
-
-
Skill
-
-
SkillDataSchema
-
-
SkillInfoSchema
-
-
SkillResponseSchema
-
-
SkillTypeTransformer
-
Transformation class that can encode an instance of Skill to String,
and decode dynamic data back to Skill.
-
SkinResponseSchema
-
-
SkinsApi
-
-
SkinSchema
-
-
SpawnEventRequestSchema
-
-
StaticDataPageAchievementSchema
-
-
StaticDataPageActiveEventSchema
-
-
StaticDataPageBadgeSchema
-
-
StaticDataPageDropRateSchema
-
-
StaticDataPageEffectSchema
-
-
StaticDataPageEventSchema
-
-
StaticDataPageItemSchema
-
-
StaticDataPageMapSchema
-
-
StaticDataPageMonsterSchema
-
-
StaticDataPageNPCItemSchema
-
-
StaticDataPageNPCSchema
-
-
-
-
StaticDataPageSeasonRewardSchema
-
-
StaticDataPageSkinSchema
-
-
StaticDataPageTaskFullSchema
-
-
StatusResponseSchema
-
-
StatusSchema
-
-
StatusSeasonRewardSchema
-
-
StorageEffectSchema
-
-
StripeSubscriptionPlan
-
Stripe subscription plan type.
-
StripeSubscriptionPlanTypeTransformer
-
Transformation class that can encode an instance of StripeSubscriptionPlan to String,
and decode dynamic data back to StripeSubscriptionPlan.
-
SubscribeRequestSchema
-
-
SubscriptionPlan
-
Subscription plan type.
-
SubscriptionPlanTypeTransformer
-
Transformation class that can encode an instance of SubscriptionPlan to String,
and decode dynamic data back to SubscriptionPlan.
-
SubscriptionResponseSchema
-
-
SubscriptionSchema
-
-
SubscriptionSchemaPurchaseSourceEnum
-
How the subscription was purchased. Mixed means both gems and member tokens were used.
-
SubscriptionSchemaPurchaseSourceEnumTypeTransformer
-
Transformation class that can encode an instance of SubscriptionSchemaPurchaseSourceEnum to String,
and decode dynamic data back to SubscriptionSchemaPurchaseSourceEnum.
-
TaskCancelledResponseSchema
-
-
TaskCancelledSchema
-
-
TaskDataSchema
-
-
TaskFullResponseSchema
-
-
TaskFullSchema
-
-
TaskResponseSchema
-
-
TasksApi
-
-
TaskSchema
-
-
TaskTradeDataSchema
-
-
TaskTradeResponseSchema
-
-
TaskTradeSchema
-
-
TaskType
-
-
TaskTypeTypeTransformer
-
Transformation class that can encode an instance of TaskType to String,
and decode dynamic data back to TaskType.
-
TokenApi
-
-
TokenResponseSchema
-
-
TransitionSchema
-
-
UnequipSchema
-
-
UseItemResponseSchema
-
-
UseItemSchema
-
-
ValidationError
-
-
XPType
-
-
XPTypeTypeTransformer
-
Transformation class that can encode an instance of XPType to String,
and decode dynamic data back to XPType.
Functions
-
decodeAsync(DeserializationMessage message)
→ Future
-
Primarily intended for use in an isolate.
-
deserializeAsync(DeserializationMessage message)
→ Future
-
Primarily intended for use in an isolate.
-
mapCastOfType<K, V>(dynamic map, String key)
→ Map<K, V>?
-
Returns a valid Map<K, V> found at the specified Map
key, null otherwise.
-
mapDateTime(dynamic map, String key, [String? pattern])
→ DateTime?
-
Returns a valid DateTime found at the specified Map
key, null otherwise.
-
mapValueOfType<T>(dynamic map, String key)
→ T?
-
Returns a valid
T value found at the specified Map key, null otherwise.
-
parameterToString(dynamic value)
→ String
-
Format the given parameter object into a String.
-
serializeAsync(Object? value)
→ Future<String>
-
Primarily intended for use in an isolate.