AccountAchievementObjectiveSchema class
Constructors
- AccountAchievementObjectiveSchema({required AchievementType type, String? target, int progress = 0, required int total})
- Returns a new AccountAchievementObjectiveSchema instance.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- progress ↔ int
-
Current progress for this objective.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target ↔ String?
-
Target of the objective (e.g., item code, monster code).
getter/setter pair
- total ↔ int
-
Total required for this objective.
getter/setter pair
- type ↔ AchievementType
-
Type of objective.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → AccountAchievementObjectiveSchema? -
Returns a new AccountAchievementObjectiveSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< AccountAchievementObjectiveSchema> -
mapFromJson(
dynamic json) → Map< String, AccountAchievementObjectiveSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< AccountAchievementObjectiveSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.