AccountAchievementSchema class

Constructors

AccountAchievementSchema({required String name, required String code, required String description, required int points, List<AccountAchievementObjectiveSchema> objectives = const [], required AchievementRewardsSchema rewards, DateTime? completedAt})
Returns a new AccountAchievementSchema instance.

Properties

code String
Code of the achievement.
getter/setter pair
completedAt DateTime?
Completion timestamp.
getter/setter pair
description String
Description of the achievement.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
name String
Name of the achievement.
getter/setter pair
objectives List<AccountAchievementObjectiveSchema>
List of objectives with progress.
getter/setter pair
points int
Points of the achievement. Used for the leaderboard.
getter/setter pair
rewards AchievementRewardsSchema
Rewards.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AccountAchievementSchema?
Returns a new AccountAchievementSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<AccountAchievementSchema>
mapFromJson(dynamic json) Map<String, AccountAchievementSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<AccountAchievementSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.