AccountDetails class
Constructors
-
AccountDetails({required String username, required bool member, required AccountStatus status, List<
String> badges = const [], List<String> skins = const [], required int achievementsPoints, required bool banned, String? banReason}) - Returns a new AccountDetails instance.
Properties
- achievementsPoints ↔ int
-
Achievement points.
getter/setter pair
-
badges
↔ List<
String> -
Account badges.
getter/setter pair
- banned ↔ bool
-
Banned.
getter/setter pair
- banReason ↔ String?
-
Ban reason.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- member ↔ bool
-
Member status.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
skins
↔ List<
String> -
Skins owned.
getter/setter pair
- status ↔ AccountStatus
-
Account status.
getter/setter pair
- username ↔ String
-
Username.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → AccountDetails? -
Returns a new AccountDetails instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< AccountDetails> -
mapFromJson(
dynamic json) → Map< String, AccountDetails> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< AccountDetails> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.