AccountsApi class

Constructors

AccountsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createAccountAccountsCreatePost(AddAccountSchema addAccountSchema) Future<ResponseSchema?>
Create Account
createAccountAccountsCreatePostWithHttpInfo(AddAccountSchema addAccountSchema) Future<Response>
Create Account
forgotPasswordAccountsForgotPasswordPost(PasswordResetRequestSchema passwordResetRequestSchema) Future<PasswordResetResponseSchema?>
Forgot Password
forgotPasswordAccountsForgotPasswordPostWithHttpInfo(PasswordResetRequestSchema passwordResetRequestSchema) Future<Response>
Forgot Password
getAccountAccountsAccountGet(String account) Future<AccountDetailsSchema?>
Get Account
getAccountAccountsAccountGetWithHttpInfo(String account) Future<Response>
Get Account
getAccountAchievementsAccountsAccountAchievementsGet(String account, {AchievementType? type, bool? completed, int? page, int? size}) Future<DataPageAccountAchievementSchema?>
Get Account Achievements
getAccountAchievementsAccountsAccountAchievementsGetWithHttpInfo(String account, {AchievementType? type, bool? completed, int? page, int? size}) Future<Response>
Get Account Achievements
getAccountCharactersAccountsAccountCharactersGet(String account) Future<CharactersListSchema?>
Get Account Characters
getAccountCharactersAccountsAccountCharactersGetWithHttpInfo(String account) Future<Response>
Get Account Characters
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetPasswordAccountsResetPasswordPost(PasswordResetConfirmSchema passwordResetConfirmSchema) Future<PasswordResetResponseSchema?>
Reset Password
resetPasswordAccountsResetPasswordPostWithHttpInfo(PasswordResetConfirmSchema passwordResetConfirmSchema) Future<Response>
Reset Password
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited