AchievementRewardsSchema class
Constructors
-
AchievementRewardsSchema({int gold = 0, List<
RewardItemSchema> items = const []}) - Returns a new AchievementRewardsSchema instance.
Properties
- gold ↔ int
-
Gold rewards.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
-
items
↔ List<
RewardItemSchema> -
Item rewards.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → AchievementRewardsSchema? -
Returns a new AchievementRewardsSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< AchievementRewardsSchema> -
mapFromJson(
dynamic json) → Map< String, AchievementRewardsSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< AchievementRewardsSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.