AchievementType class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) AchievementType?
listFromJson(dynamic json, {bool growable = false}) List<AchievementType>

Constants

combatDrop → const AchievementType
combatKill → const AchievementType
combatLevel → const AchievementType
crafting → const AchievementType
gathering → const AchievementType
npcBuy → const AchievementType
npcSell → const AchievementType
other → const AchievementType
recycling → const AchievementType
task → const AchievementType
use → const AchievementType
values → const List<AchievementType>
List of all possible values in this AchievementType.