AchievementsApi class

Constructors

AchievementsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAchievementAchievementsCodeGet(String code) Future<AchievementResponseSchema?>
Get Achievement
getAchievementAchievementsCodeGetWithHttpInfo(String code) Future<Response>
Get Achievement
getAllAchievementsAchievementsGet({AchievementType? type, int? page, int? size}) Future<StaticDataPageAchievementSchema?>
Get All Achievements
getAllAchievementsAchievementsGetWithHttpInfo({AchievementType? type, int? page, int? size}) Future<Response>
Get All Achievements
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited