ActionType class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) ActionType?
listFromJson(dynamic json, {bool growable = false}) List<ActionType>

Constants

buyBankExpansion → const ActionType
buyGe → const ActionType
buyNpc → const ActionType
cancelGe → const ActionType
changeSkin → const ActionType
claimItem → const ActionType
crafting → const ActionType
createBuyOrderGe → const ActionType
deleteItem → const ActionType
depositGold → const ActionType
depositItem → const ActionType
equip → const ActionType
fight → const ActionType
fillBuyOrderGe → const ActionType
gathering → const ActionType
giveGold → const ActionType
giveItem → const ActionType
movement → const ActionType
multiFight → const ActionType
recycling → const ActionType
rename → const ActionType
rest → const ActionType
sandboxGiveGold → const ActionType
sandboxGiveItem → const ActionType
sandboxGiveXp → const ActionType
sellGe → const ActionType
sellNpc → const ActionType
task → const ActionType
transition → const ActionType
unequip → const ActionType
use → const ActionType
values → const List<ActionType>
List of all possible values in this ActionType.
withdrawGold → const ActionType
withdrawItem → const ActionType