ActiveCharacterSchema class

Constructors

ActiveCharacterSchema({required String name, required String account, required CharacterSkin skin, required int x, required int y, required MapLayer layer, required int mapId})
Returns a new ActiveCharacterSchema instance.

Properties

account String
Account name.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
layer MapLayer
Character current layer.
getter/setter pair
mapId int
Character current map ID.
getter/setter pair
name String
Name of the character.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skin CharacterSkin
Character skin code.
getter/setter pair
x int
Character x coordinate.
getter/setter pair
y int
Character y coordinate.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ActiveCharacterSchema?
Returns a new ActiveCharacterSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ActiveCharacterSchema>
mapFromJson(dynamic json) Map<String, ActiveCharacterSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ActiveCharacterSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.