ActiveEventSchema class
Constructors
- ActiveEventSchema({required String name, required String code, required MapSchema map, required MapSchema previousMap, required int duration, required DateTime expiration, required DateTime createdAt})
- Returns a new ActiveEventSchema instance.
Properties
- code ↔ String
-
Code of the event.
getter/setter pair
- createdAt ↔ DateTime
-
Start datetime.
getter/setter pair
- duration ↔ int
-
Duration in minutes.
getter/setter pair
- expiration ↔ DateTime
-
Expiration datetime.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- map ↔ MapSchema
-
Map of the event.
getter/setter pair
- name ↔ String
-
Name of the event.
getter/setter pair
- previousMap ↔ MapSchema
-
Previous map skin.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → ActiveEventSchema? -
Returns a new ActiveEventSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< ActiveEventSchema> -
mapFromJson(
dynamic json) → Map< String, ActiveEventSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< ActiveEventSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.