AddAccountSchema class

Constructors

AddAccountSchema({required String username, required String password, required String email})
Returns a new AddAccountSchema instance.

Properties

email String
Your email.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
password String
Your password.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
Your desired username.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AddAccountSchema?
Returns a new AddAccountSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<AddAccountSchema>
mapFromJson(dynamic json) Map<String, AddAccountSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<AddAccountSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.