AddCharacterSchema class

Constructors

AddCharacterSchema({required String name, required CharacterSkin skin})
Returns a new AddCharacterSchema instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
Your desired character name. It's unique and all players can see it.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skin CharacterSkin
Your desired skin. Skins unlocked by default: 'men1', 'men2', 'men3', 'women1', 'women2', 'women3'.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AddCharacterSchema?
Returns a new AddCharacterSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<AddCharacterSchema>
mapFromJson(dynamic json) Map<String, AddCharacterSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<AddCharacterSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.