AssistantAnswerDataSchema class
Constructors
- AssistantAnswerDataSchema({required String answer, required RateLimitScopeSchema assistant, required bool paidWithGems})
- Returns a new AssistantAnswerDataSchema instance.
Properties
- answer ↔ String
-
The assistant's answer.
getter/setter pair
- assistant ↔ RateLimitScopeSchema
-
Updated assistant rate limit after this request.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- paidWithGems ↔ bool
-
Whether this question cost 1 gem.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → AssistantAnswerDataSchema? -
Returns a new AssistantAnswerDataSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< AssistantAnswerDataSchema> -
mapFromJson(
dynamic json) → Map< String, AssistantAnswerDataSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< AssistantAnswerDataSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.