BadgeSchema class

Constructors

BadgeSchema({required String code, int? season, required String description, List<BadgeConditionSchema> conditions = const []})
Returns a new BadgeSchema instance.

Properties

code String
Code of the badge. This is the badge's unique identifier (ID).
getter/setter pair
conditions List<BadgeConditionSchema>
Conditions to get the badge.
getter/setter pair
description String
Description of the badge.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
season int?
Season of the badge.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) BadgeSchema?
Returns a new BadgeSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<BadgeSchema>
mapFromJson(dynamic json) Map<String, BadgeSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<BadgeSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.