BadgesApi class

Constructors

BadgesApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllBadgesBadgesGet({int? page, int? size}) Future<StaticDataPageBadgeSchema?>
Get All Badges
getAllBadgesBadgesGetWithHttpInfo({int? page, int? size}) Future<Response>
Get All Badges
getBadgeBadgesCodeGet(String code) Future<BadgeResponseSchema?>
Get Badge
getBadgeBadgesCodeGetWithHttpInfo(String code) Future<Response>
Get Badge
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited