BankGoldTransactionSchema class

Constructors

BankGoldTransactionSchema({required CooldownSchema cooldown, required GoldSchema bank, required CharacterSchema character})
Returns a new BankGoldTransactionSchema instance.

Properties

bank GoldSchema
Bank details.
getter/setter pair
character CharacterSchema
Player details.
getter/setter pair
cooldown CooldownSchema
Cooldown details.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) BankGoldTransactionSchema?
Returns a new BankGoldTransactionSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<BankGoldTransactionSchema>
mapFromJson(dynamic json) Map<String, BankGoldTransactionSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<BankGoldTransactionSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.