BankItemTransactionSchema class

Constructors

BankItemTransactionSchema({required CooldownSchema cooldown, List<SimpleItemSchema> items = const [], List<SimpleItemSchema> bank = const [], required CharacterSchema character})
Returns a new BankItemTransactionSchema instance.

Properties

bank List<SimpleItemSchema>
Items in your banks.
getter/setter pair
character CharacterSchema
Player details.
getter/setter pair
cooldown CooldownSchema
Cooldown details.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
items List<SimpleItemSchema>
Items details.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) BankItemTransactionSchema?
Returns a new BankItemTransactionSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<BankItemTransactionSchema>
mapFromJson(dynamic json) Map<String, BankItemTransactionSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<BankItemTransactionSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.