BankSchema class
Constructors
- BankSchema({required int slots, required int expansions, required int nextExpansionCost, required int gold})
- Returns a new BankSchema instance.
Properties
- expansions ↔ int
-
Bank expansions.
getter/setter pair
- gold ↔ int
-
Quantity of gold in your bank.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- nextExpansionCost ↔ int
-
Next expansion cost.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slots ↔ int
-
Maximum slots in your bank.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → BankSchema? -
Returns a new BankSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< BankSchema> -
mapFromJson(
dynamic json) → Map< String, BankSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< BankSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.