BlockedHitsSchema class

Constructors

BlockedHitsSchema({required int fire, required int earth, required int water, required int air, required int total})
Returns a new BlockedHitsSchema instance.

Properties

air int
The amount of air hits blocked.
getter/setter pair
earth int
The amount of earth hits blocked.
getter/setter pair
fire int
The amount of fire hits blocked.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
The amount of total hits blocked.
getter/setter pair
water int
The amount of water hits blocked.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) BlockedHitsSchema?
Returns a new BlockedHitsSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<BlockedHitsSchema>
mapFromJson(dynamic json) Map<String, BlockedHitsSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<BlockedHitsSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.