BuySkinResponseDataSchema class

Constructors

BuySkinResponseDataSchema({List<String> skins = const [], required String skin, required int gems})
Returns a new BuySkinResponseDataSchema instance.

Properties

gems int
Remaining gem balance.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skin String
Code of the purchased skin.
getter/setter pair
skins List<String>
Updated list of owned skins.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) BuySkinResponseDataSchema?
Returns a new BuySkinResponseDataSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<BuySkinResponseDataSchema>
mapFromJson(dynamic json) Map<String, BuySkinResponseDataSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<BuySkinResponseDataSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.