ChangeEmailSchema class

Constructors

ChangeEmailSchema({required String currentEmail, required String newEmail})
Returns a new ChangeEmailSchema instance.

Properties

currentEmail String
Your current email.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
newEmail String
New email.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ChangeEmailSchema?
Returns a new ChangeEmailSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ChangeEmailSchema>
mapFromJson(dynamic json) Map<String, ChangeEmailSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ChangeEmailSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.