ChangePasswordSchema class

Constructors

ChangePasswordSchema({required String currentPassword, required String newPassword})
Returns a new ChangePasswordSchema instance.

Properties

currentPassword String
Your password.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
newPassword String
New password.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ChangePasswordSchema?
Returns a new ChangePasswordSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ChangePasswordSchema>
mapFromJson(dynamic json) Map<String, ChangePasswordSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ChangePasswordSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.