CharacterFightDataSchema class
Constructors
-
CharacterFightDataSchema({required CooldownSchema cooldown, required CharacterFightSchema fight, List<
CharacterSchema> characters = const []}) - Returns a new CharacterFightDataSchema instance.
Properties
-
characters
↔ List<
CharacterSchema> -
All characters involved.
getter/setter pair
- cooldown ↔ CooldownSchema
-
Cooldown details.
getter/setter pair
- fight ↔ CharacterFightSchema
-
Character fight details.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → CharacterFightDataSchema? -
Returns a new CharacterFightDataSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< CharacterFightDataSchema> -
mapFromJson(
dynamic json) → Map< String, CharacterFightDataSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< CharacterFightDataSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.