CharacterFightSchema class

Constructors

CharacterFightSchema({required FightResult result, required int turns, required String opponent, List<String> logs = const [], List<CharacterMultiFightResultSchema> characters = const []})
Returns a new CharacterFightSchema instance.

Properties

characters List<CharacterMultiFightResultSchema>
Results for each character.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
logs List<String>
The fight logs.
getter/setter pair
opponent String
The code of the monster fought.
getter/setter pair
result FightResult
The result of the fight.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
turns int
Numbers of the turns of the combat.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) CharacterFightSchema?
Returns a new CharacterFightSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<CharacterFightSchema>
mapFromJson(dynamic json) Map<String, CharacterFightSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<CharacterFightSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.