CharacterMovementDataSchema class
Constructors
-
CharacterMovementDataSchema({required CooldownSchema cooldown, required MapSchema destination, List<
List< path = const [], required CharacterSchema character})Object> > - Returns a new CharacterMovementDataSchema instance.
Properties
- character ↔ CharacterSchema
-
Character details.
getter/setter pair
- cooldown ↔ CooldownSchema
-
Cooldown details
getter/setter pair
- destination ↔ MapSchema
-
Destination details.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
-
path
↔ List<
List< Object> > -
Path taken from start to destination (list of coordinates)
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → CharacterMovementDataSchema? -
Returns a new CharacterMovementDataSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< CharacterMovementDataSchema> -
mapFromJson(
dynamic json) → Map< String, CharacterMovementDataSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< CharacterMovementDataSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.