CharacterMultiFightResultSchema class

Constructors

CharacterMultiFightResultSchema({required String characterName, required int xp, required int gold, List<DropSchema> drops = const [], required int finalHp})
Returns a new CharacterMultiFightResultSchema instance.

Properties

characterName String
Name of the character.
getter/setter pair
drops List<DropSchema>
Items dropped for this character.
getter/setter pair
finalHp int
Character's HP at the end of combat.
getter/setter pair
gold int
Gold gained by this character.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xp int
XP gained by this character.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) CharacterMultiFightResultSchema?
Returns a new CharacterMultiFightResultSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<CharacterMultiFightResultSchema>
mapFromJson(dynamic json) Map<String, CharacterMultiFightResultSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<CharacterMultiFightResultSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.