CharacterSkin class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) CharacterSkin?
listFromJson(dynamic json, {bool growable = false}) List<CharacterSkin>

Constants

corrupted1 → const CharacterSkin
goblin1 → const CharacterSkin
marauder1 → const CharacterSkin
men1 → const CharacterSkin
men2 → const CharacterSkin
men3 → const CharacterSkin
values → const List<CharacterSkin>
List of all possible values in this CharacterSkin.
women1 → const CharacterSkin
women2 → const CharacterSkin
women3 → const CharacterSkin
zombie1 → const CharacterSkin