CharactersApi class

Constructors

CharactersApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createCharacterCharactersCreatePost(AddCharacterSchema addCharacterSchema) Future<CharacterResponseSchema?>
Create Character
createCharacterCharactersCreatePostWithHttpInfo(AddCharacterSchema addCharacterSchema) Future<Response>
Create Character
deleteCharacterCharactersDeletePost(DeleteCharacterSchema deleteCharacterSchema) Future<CharacterResponseSchema?>
Delete Character
deleteCharacterCharactersDeletePostWithHttpInfo(DeleteCharacterSchema deleteCharacterSchema) Future<Response>
Delete Character
getActiveCharactersCharactersActiveGet({int? page, int? size}) Future<DataPageActiveCharacterSchema?>
Get Active Characters
getActiveCharactersCharactersActiveGetWithHttpInfo({int? page, int? size}) Future<Response>
Get Active Characters
getCharacterCharactersNameGet(String name) Future<CharacterResponseSchema?>
Get Character
getCharacterCharactersNameGetWithHttpInfo(String name) Future<Response>
Get Character
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited