getCharacterStatsCharactersNameStatsGet method

Future<CharacterStatsResponseSchema?> getCharacterStatsCharactersNameStatsGet(
  1. String name, {
  2. Future<void>? abortTrigger,
})

Get Character Stats

Retrieve gameplay statistics for a character. Stats are only visible if the character's account has an active subscription. Statistics are still collected for all accounts regardless of subscription status.

Parameters:

  • String name (required): The name of the character.

Implementation

Future<CharacterStatsResponseSchema?> getCharacterStatsCharactersNameStatsGet(
  String name, {
  Future<void>? abortTrigger,
}) async {
  final response = await getCharacterStatsCharactersNameStatsGetWithHttpInfo(
    name,
    abortTrigger: abortTrigger,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty &&
      response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'CharacterStatsResponseSchema',
    ) as CharacterStatsResponseSchema;
  }
  return null;
}