CheckoutResponseSchema class
Constructors
- CheckoutResponseSchema({required String checkoutUrl, required String sessionId})
- Returns a new CheckoutResponseSchema instance.
Properties
- checkoutUrl ↔ String
-
Stripe checkout URL for payment.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId ↔ String
-
Stripe checkout session ID.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → CheckoutResponseSchema? -
Returns a new CheckoutResponseSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< CheckoutResponseSchema> -
mapFromJson(
dynamic json) → Map< String, CheckoutResponseSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< CheckoutResponseSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.