ClaimPendingItemDataSchema class

Constructors

ClaimPendingItemDataSchema({required CooldownSchema cooldown, required PendingItemSchema item, required CharacterSchema character})
Returns a new ClaimPendingItemDataSchema instance.

Properties

character CharacterSchema
Character details.
getter/setter pair
cooldown CooldownSchema
Cooldown details.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
item PendingItemSchema
The claimed pending item.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ClaimPendingItemDataSchema?
Returns a new ClaimPendingItemDataSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ClaimPendingItemDataSchema>
mapFromJson(dynamic json) Map<String, ClaimPendingItemDataSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ClaimPendingItemDataSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.