CombatSimulationDataSchema class

Constructors

CombatSimulationDataSchema({List<CombatResultSchema> results = const [], required int wins, required int losses, required num winrate})
Returns a new CombatSimulationDataSchema instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
losses int
Total number of defeats.
getter/setter pair
results List<CombatResultSchema>
Results from each combat iteration.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
winrate num
Win rate percentage (0-100).
getter/setter pair
wins int
Total number of victories.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) CombatSimulationDataSchema?
Returns a new CombatSimulationDataSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<CombatSimulationDataSchema>
mapFromJson(dynamic json) Map<String, CombatSimulationDataSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<CombatSimulationDataSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.