CombatSimulationRequestSchema class

Constructors

CombatSimulationRequestSchema({List<FakeCharacterSchema> characters = const [], required String monster, required int iterations})
Returns a new CombatSimulationRequestSchema instance.

Properties

characters List<FakeCharacterSchema>
List of fake characters (1-3).
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
iterations int
Number of combat iterations to simulate.
getter/setter pair
monster String
Monster code to fight against.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) CombatSimulationRequestSchema?
Returns a new CombatSimulationRequestSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<CombatSimulationRequestSchema>
mapFromJson(dynamic json) Map<String, CombatSimulationRequestSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<CombatSimulationRequestSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.