ConditionOperator class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) ConditionOperator?
listFromJson(dynamic json, {bool growable = false}) List<ConditionOperator>

Constants

achievementUnlocked → const ConditionOperator
cost → const ConditionOperator
eq → const ConditionOperator
gt → const ConditionOperator
hasItem → const ConditionOperator
lt → const ConditionOperator
ne → const ConditionOperator
values → const List<ConditionOperator>
List of all possible values in this ConditionOperator.