ConditionSchema class

Constructors

ConditionSchema({required String code, required ConditionOperator operator_, required int value})
Returns a new ConditionSchema instance.

Properties

code String
Condition code.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
operator_ ConditionOperator
Condition operator.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
Condition value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ConditionSchema?
Returns a new ConditionSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ConditionSchema>
mapFromJson(dynamic json) Map<String, ConditionSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ConditionSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.