CooldownSchema class

Constructors

CooldownSchema({required int totalSeconds, required int remainingSeconds, required DateTime startedAt, required DateTime expiration, required ActionType reason})
Returns a new CooldownSchema instance.

Properties

expiration DateTime
The expiration of the cooldown.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
reason ActionType
The reason of the cooldown.
getter/setter pair
remainingSeconds int
The remaining seconds of the cooldown.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt DateTime
The start of the cooldown.
getter/setter pair
totalSeconds int
The total seconds of the cooldown.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) CooldownSchema?
Returns a new CooldownSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<CooldownSchema>
mapFromJson(dynamic json) Map<String, CooldownSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<CooldownSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.