CraftSchema class

Constructors

CraftSchema({CraftSkill? skill, int? level, List<SimpleItemSchema> items = const [], int? quantity})
Returns a new CraftSchema instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
items List<SimpleItemSchema>
List of items required to craft the item.
getter/setter pair
level int?
The skill level required to craft the item.
getter/setter pair
quantity int?
Quantity of items crafted.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skill CraftSkill?
Skill required to craft the item.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) CraftSchema?
Returns a new CraftSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<CraftSchema>
mapFromJson(dynamic json) Map<String, CraftSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<CraftSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.