CraftingSchema class

Constructors

CraftingSchema({required String code, int quantity = 1})
Returns a new CraftingSchema instance.

Properties

code String
Craft code.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
quantity int
Quantity of items to craft.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) CraftingSchema?
Returns a new CraftingSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<CraftingSchema>
mapFromJson(dynamic json) Map<String, CraftingSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<CraftingSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.