DropRateSchema class
Constructors
- DropRateSchema({required String code, required int rate, required int minQuantity, required int maxQuantity})
- Returns a new DropRateSchema instance.
Properties
- code ↔ String
-
Item code.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxQuantity ↔ int
-
Maximum quantity.
getter/setter pair
- minQuantity ↔ int
-
Minimum quantity.
getter/setter pair
- rate ↔ int
-
Chance rate. (1/rate)
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → DropRateSchema? -
Returns a new DropRateSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< DropRateSchema> -
mapFromJson(
dynamic json) → Map< String, DropRateSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< DropRateSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.