EffectsApi class

Constructors

EffectsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllEffectsEffectsGet({int? page, int? size}) Future<StaticDataPageEffectSchema?>
Get All Effects
getAllEffectsEffectsGetWithHttpInfo({int? page, int? size}) Future<Response>
Get All Effects
getEffectEffectsCodeGet(String code) Future<EffectResponseSchema?>
Get Effect
getEffectEffectsCodeGetWithHttpInfo(String code) Future<Response>
Get Effect
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited