getAllEffectsEffectsGet method
Get All Effects
List of all effects. Effects are used by equipment, tools, runes, consumables and monsters. An effect is an action that produces an effect on the game.
Parameters:
Implementation
Future<StaticDataPageEffectSchema?> getAllEffectsEffectsGet({
int? page,
int? size,
}) async {
final response = await getAllEffectsEffectsGetWithHttpInfo(
page: page,
size: size,
);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty &&
response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(
await _decodeBodyBytes(response),
'StaticDataPageEffectSchema',
) as StaticDataPageEffectSchema;
}
return null;
}