getAllEffectsEffectsGetWithHttpInfo method
Get All Effects
List of all effects. Effects are used by equipment, tools, runes, consumables and monsters. An effect is an action that produces an effect on the game.
Note: This method returns the HTTP Response.
Parameters:
Implementation
Future<Response> getAllEffectsEffectsGetWithHttpInfo({
int? page,
int? size,
}) async {
// ignore: prefer_const_declarations
final path = r'/effects';
// ignore: prefer_final_locals
Object? postBody;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
if (page != null) {
queryParams.addAll(_queryParams('', 'page', page));
}
if (size != null) {
queryParams.addAll(_queryParams('', 'size', size));
}
const contentTypes = <String>[];
return apiClient.invokeAPI(
path,
'GET',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes.first,
);
}