ErrorSchema class

Constructors

ErrorSchema({required int code, required String message, Map<String, Object> data = const {}})
Returns a new ErrorSchema instance.

Properties

code int
Error code
getter/setter pair
data Map<String, Object>
Additional error data (used primarily for validation errors)
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
message String
Error message
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ErrorSchema?
Returns a new ErrorSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ErrorSchema>
mapFromJson(dynamic json) Map<String, ErrorSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ErrorSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.