EventMapSchema class

Constructors

EventMapSchema({required int mapId, required int x, required int y, required String layer, required String skin})
Returns a new EventMapSchema instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
layer String
Layer of the map.
getter/setter pair
mapId int
ID of the map.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skin String
Map skin of the map
getter/setter pair
x int
Position X of the map.
getter/setter pair
y int
Position Y of the map.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) EventMapSchema?
Returns a new EventMapSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<EventMapSchema>
mapFromJson(dynamic json) Map<String, EventMapSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<EventMapSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.