EventSchema class
Constructors
-
EventSchema({required String name, required String code, required EventContentSchema content, List<
EventMapSchema> maps = const [], required int duration, required int rate}) - Returns a new EventSchema instance.
Properties
- code ↔ String
-
Code of the event.
getter/setter pair
- content ↔ EventContentSchema
-
Content of the event.
getter/setter pair
- duration ↔ int
-
Duration in minutes.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
-
maps
↔ List<
EventMapSchema> -
Map list of the event.
getter/setter pair
- name ↔ String
-
Name of the event.
getter/setter pair
- rate ↔ int
-
Rate spawn of the event. (1/rate every minute)
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → EventSchema? -
Returns a new EventSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< EventSchema> -
mapFromJson(
dynamic json) → Map< String, EventSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< EventSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.