transition property

TransitionSchema? transition
getter/setter pair

Transition to add to the map when event is active.

Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.

Implementation

TransitionSchema? transition;