EventsApi class

Constructors

EventsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllActiveEventsEventsActiveGet({int? page, int? size}) Future<StaticDataPageActiveEventSchema?>
Get All Active Events
getAllActiveEventsEventsActiveGetWithHttpInfo({int? page, int? size}) Future<Response>
Get All Active Events
getAllEventsEventsGet({MapContentType? type, int? page, int? size}) Future<StaticDataPageEventSchema?>
Get All Events
getAllEventsEventsGetWithHttpInfo({MapContentType? type, int? page, int? size}) Future<Response>
Get All Events
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
spawnEventEventsSpawnPost(SpawnEventRequest spawnEventRequest) Future<ActiveEventResponseSchema?>
Spawn Event
spawnEventEventsSpawnPostWithHttpInfo(SpawnEventRequest spawnEventRequest) Future<Response>
Spawn Event
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited