GEBuyOrderCreationSchema class

Constructors

GEBuyOrderCreationSchema({required String code, required int quantity, required int price})
Returns a new GEBuyOrderCreationSchema instance.

Properties

code String
Item code.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
price int
Item price per unit.
getter/setter pair
quantity int
Item quantity.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) GEBuyOrderCreationSchema?
Returns a new GEBuyOrderCreationSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<GEBuyOrderCreationSchema>
mapFromJson(dynamic json) Map<String, GEBuyOrderCreationSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<GEBuyOrderCreationSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.