GEFillBuyOrderSchema class
Constructors
- GEFillBuyOrderSchema({required String id, required int quantity})
- Returns a new GEFillBuyOrderSchema instance.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → GEFillBuyOrderSchema? -
Returns a new GEFillBuyOrderSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< GEFillBuyOrderSchema> -
mapFromJson(
dynamic json) → Map< String, GEFillBuyOrderSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< GEFillBuyOrderSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.