GEOrderCreatedSchema class

Constructors

GEOrderCreatedSchema({required String id, required DateTime createdAt, required String code, required int quantity, required int price, required int totalPrice})
Returns a new GEOrderCreatedSchema instance.

Properties

code String
Item code.
getter/setter pair
createdAt DateTime
Order created at.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id String
Order id.
getter/setter pair
price int
Item price per unit.
getter/setter pair
quantity int
Item quantity.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalPrice int
Total price.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) GEOrderCreatedSchema?
Returns a new GEOrderCreatedSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<GEOrderCreatedSchema>
mapFromJson(dynamic json) Map<String, GEOrderCreatedSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<GEOrderCreatedSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.