GEOrderSchema class

Constructors

GEOrderSchema({required String id, GEOrderType? type, String? account, required String code, required int quantity, required int price, required DateTime createdAt})
Returns a new GEOrderSchema instance.

Properties

account String?
Account linked to the order.
getter/setter pair
code String
Item code.
getter/setter pair
createdAt DateTime
Order created at.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id String
Order id.
getter/setter pair
price int
Item price per unit.
getter/setter pair
quantity int
Item quantity.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type GEOrderType?
Order type (sell or buy).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) GEOrderSchema?
Returns a new GEOrderSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<GEOrderSchema>
mapFromJson(dynamic json) Map<String, GEOrderSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<GEOrderSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.