GETransactionSchema class

Constructors

GETransactionSchema({required String id, required String code, required int quantity, required int price, required int totalPrice})
Returns a new GETransactionSchema instance.

Properties

code String
Item code.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id String
Order id.
getter/setter pair
price int
Item price.
getter/setter pair
quantity int
Item quantity.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalPrice int
Total price of the transaction.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) GETransactionSchema?
Returns a new GETransactionSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<GETransactionSchema>
mapFromJson(dynamic json) Map<String, GETransactionSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<GETransactionSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.