GameAssistantApi class

Constructors

GameAssistantApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

askGameAssistantGameAssistantAskPost(AssistantQuestionSchema assistantQuestionSchema, {Future<void>? abortTrigger}) Future<AssistantAnswerSchema?>
Ask Game Assistant
askGameAssistantGameAssistantAskPostWithHttpInfo(AssistantQuestionSchema assistantQuestionSchema, {Future<void>? abortTrigger}) Future<Response>
Ask Game Assistant
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited