askGameAssistantGameAssistantAskPostWithHttpInfo method
Future<Response>
askGameAssistantGameAssistantAskPostWithHttpInfo(
- AssistantQuestionSchema assistantQuestionSchema, {
- Future<
void> ? abortTrigger,
Ask Game Assistant
Ask the game assistant a question about game mechanics or public API usage. An active membership is required. Members receive a limited number of free questions per day. When no free question is available, the request can spend 1 gem with pay_with_gems=true.
Note: This method returns the HTTP Response.
Parameters:
- AssistantQuestionSchema assistantQuestionSchema (required):
Implementation
Future<Response> askGameAssistantGameAssistantAskPostWithHttpInfo(
AssistantQuestionSchema assistantQuestionSchema, {
Future<void>? abortTrigger,
}) async {
// ignore: prefer_const_declarations
final path = r'/game_assistant/ask';
// ignore: prefer_final_locals
Object? postBody = assistantQuestionSchema;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
const contentTypes = <String>['application/json'];
return apiClient.invokeAPI(
path,
'POST',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes.first,
abortTrigger: abortTrigger,
);
}