GemShopCatalogDataSchema class

Constructors

GemShopCatalogDataSchema({List<GemShopSkinCatalogItemSchema> skins = const [], List<GemShopSpawnEventCatalogItemSchema> spawnEvents = const [], List<GemShopSubscriptionCatalogItemSchema> subscriptions = const [], List<GemShopCustomDesignCatalogItemSchema> customDesigns = const []})
Returns a new GemShopCatalogDataSchema instance.

Properties

customDesigns List<GemShopCustomDesignCatalogItemSchema>
Gem-shop custom designs.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skins List<GemShopSkinCatalogItemSchema>
Gem-shop skins.
getter/setter pair
spawnEvents List<GemShopSpawnEventCatalogItemSchema>
Gem-shop event spawns.
getter/setter pair
subscriptions List<GemShopSubscriptionCatalogItemSchema>
Gem-shop subscriptions.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) GemShopCatalogDataSchema?
Returns a new GemShopCatalogDataSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<GemShopCatalogDataSchema>
mapFromJson(dynamic json) Map<String, GemShopCatalogDataSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<GemShopCatalogDataSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.