GemShopCustomDesignPurchaseResponseDataSchema class

Constructors

GemShopCustomDesignPurchaseResponseDataSchema({required String code, required String name, required int gems, required int cost})
Returns a new GemShopCustomDesignPurchaseResponseDataSchema instance.

Properties

code String
Purchased custom design code.
getter/setter pair
cost int
Gem cost of the purchase.
getter/setter pair
gems int
Remaining gem balance.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
name String
Purchased custom design name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) GemShopCustomDesignPurchaseResponseDataSchema?
Returns a new GemShopCustomDesignPurchaseResponseDataSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<GemShopCustomDesignPurchaseResponseDataSchema>
mapFromJson(dynamic json) Map<String, GemShopCustomDesignPurchaseResponseDataSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<GemShopCustomDesignPurchaseResponseDataSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.