GemShopSkinCatalogItemSchema class

Constructors

GemShopSkinCatalogItemSchema({required String code, required String name, required String description, required int price})
Returns a new GemShopSkinCatalogItemSchema instance.

Properties

code String
Skin code.
getter/setter pair
description String
Skin description.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
name String
Skin name.
getter/setter pair
price int
Skin price in gems.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) GemShopSkinCatalogItemSchema?
Returns a new GemShopSkinCatalogItemSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<GemShopSkinCatalogItemSchema>
mapFromJson(dynamic json) Map<String, GemShopSkinCatalogItemSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<GemShopSkinCatalogItemSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.