GemShopSpawnEventCatalogItemSchema class

Constructors

GemShopSpawnEventCatalogItemSchema({required String code, required String name, required MapContentType contentType, required String contentCode, required int duration, required int price})
Returns a new GemShopSpawnEventCatalogItemSchema instance.

Properties

code String
Event code.
getter/setter pair
contentCode String
Spawned content code.
getter/setter pair
contentType MapContentType
Spawned content type.
getter/setter pair
duration int
Event duration in minutes.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
name String
Event name.
getter/setter pair
price int
Spawn cost in gems.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) GemShopSpawnEventCatalogItemSchema?
Returns a new GemShopSpawnEventCatalogItemSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<GemShopSpawnEventCatalogItemSchema>
mapFromJson(dynamic json) Map<String, GemShopSpawnEventCatalogItemSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<GemShopSpawnEventCatalogItemSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.