GemShopSubscriptionResponseDataSchema class

Constructors

GemShopSubscriptionResponseDataSchema({required bool member, required DateTime memberExpiration, required int gems, required int cost})
Returns a new GemShopSubscriptionResponseDataSchema instance.

Properties

cost int
Gem cost of the purchase.
getter/setter pair
gems int
Remaining gem balance.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
member bool
Whether the account is now a member.
getter/setter pair
memberExpiration DateTime
Membership expiration date.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) GemShopSubscriptionResponseDataSchema?
Returns a new GemShopSubscriptionResponseDataSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<GemShopSubscriptionResponseDataSchema>
mapFromJson(dynamic json) Map<String, GemShopSubscriptionResponseDataSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<GemShopSubscriptionResponseDataSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.