GemsShopApi class

Constructors

GemsShopApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buyCustomDesignGemsShopBuyCustomDesignPost(BuyCustomDesignRequestSchema buyCustomDesignRequestSchema, {Future<void>? abortTrigger}) Future<GemShopCustomDesignPurchaseResponseSchema?>
Buy Custom Design
buyCustomDesignGemsShopBuyCustomDesignPostWithHttpInfo(BuyCustomDesignRequestSchema buyCustomDesignRequestSchema, {Future<void>? abortTrigger}) Future<Response>
Buy Custom Design
buySkinGemsShopSkinPost(BuySkinRequestSchema buySkinRequestSchema, {Future<void>? abortTrigger}) Future<BuySkinResponseSchema?>
Buy Skin
buySkinGemsShopSkinPostWithHttpInfo(BuySkinRequestSchema buySkinRequestSchema, {Future<void>? abortTrigger}) Future<Response>
Buy Skin
buySpawnEventGemsShopSpawnEventPost(SpawnEventRequestSchema spawnEventRequestSchema, {Future<void>? abortTrigger}) Future<ActiveEventResponseSchema?>
Buy Spawn Event
buySpawnEventGemsShopSpawnEventPostWithHttpInfo(SpawnEventRequestSchema spawnEventRequestSchema, {Future<void>? abortTrigger}) Future<Response>
Buy Spawn Event
buySubscriptionGemsShopSubscriptionPost({Future<void>? abortTrigger}) Future<GemShopSubscriptionResponseSchema?>
Buy Subscription
buySubscriptionGemsShopSubscriptionPostWithHttpInfo({Future<void>? abortTrigger}) Future<Response>
Buy Subscription
getCatalogGemsShopGet({Future<void>? abortTrigger}) Future<GemShopCatalogResponseSchema?>
Get Catalog
getCatalogGemsShopGetWithHttpInfo({Future<void>? abortTrigger}) Future<Response>
Get Catalog
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited