buySkinGemsShopSkinPost method

Future<BuySkinResponseSchema?> buySkinGemsShopSkinPost(
  1. BuySkinRequestSchema buySkinRequestSchema, {
  2. Future<void>? abortTrigger,
})

Buy Skin

Buy a skin from the gems shop using gems.

Parameters:

Implementation

Future<BuySkinResponseSchema?> buySkinGemsShopSkinPost(
  BuySkinRequestSchema buySkinRequestSchema, {
  Future<void>? abortTrigger,
}) async {
  final response = await buySkinGemsShopSkinPostWithHttpInfo(
    buySkinRequestSchema,
    abortTrigger: abortTrigger,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty &&
      response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'BuySkinResponseSchema',
    ) as BuySkinResponseSchema;
  }
  return null;
}