GiveGoldDataSchema class

Constructors

GiveGoldDataSchema({required CooldownSchema cooldown, required int quantity, required CharacterSchema receiverCharacter, required CharacterSchema character})
Returns a new GiveGoldDataSchema instance.

Properties

character CharacterSchema
Character details.
getter/setter pair
cooldown CooldownSchema
Cooldown details.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
quantity int
Quantity of gold given.
getter/setter pair
receiverCharacter CharacterSchema
Character details of the receiving character.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) GiveGoldDataSchema?
Returns a new GiveGoldDataSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<GiveGoldDataSchema>
mapFromJson(dynamic json) Map<String, GiveGoldDataSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<GiveGoldDataSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.