GrandExchangeApi class

Constructors

GrandExchangeApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getGeHistoryGrandexchangeHistoryCodeGet(String code, {String? account, int? page, int? size}) Future<DataPageGeOrderHistorySchema?>
Get Ge History
getGeHistoryGrandexchangeHistoryCodeGetWithHttpInfo(String code, {String? account, int? page, int? size}) Future<Response>
Get Ge History
getGeOrderGrandexchangeOrdersIdGet(String id) Future<GEOrderResponseSchema?>
Get Ge Order
getGeOrderGrandexchangeOrdersIdGetWithHttpInfo(String id) Future<Response>
Get Ge Order
getGeOrdersGrandexchangeOrdersGet({String? code, String? account, GEOrderType? type, int? page, int? size}) Future<DataPageGEOrderSchema?>
Get Ge Orders
getGeOrdersGrandexchangeOrdersGetWithHttpInfo({String? code, String? account, GEOrderType? type, int? page, int? size}) Future<Response>
Get Ge Orders
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited