getGeHistoryGrandexchangeHistoryCodeGet method

Future<DataPageGeOrderHistorySchema?> getGeHistoryGrandexchangeHistoryCodeGet(
  1. String code, {
  2. String? account,
  3. int? page,
  4. int? size,
})

Get Ge History

Fetch the transaction history of the item for the last 7 days (buy and sell orders).

Parameters:

  • String code (required): The code of the item.

  • String account: Account involved in the transaction (matches either seller or buyer).

  • int page: Page number

  • int size: Page size

Implementation

Future<DataPageGeOrderHistorySchema?> getGeHistoryGrandexchangeHistoryCodeGet(
  String code, {
  String? account,
  int? page,
  int? size,
}) async {
  final response = await getGeHistoryGrandexchangeHistoryCodeGetWithHttpInfo(
    code,
    account: account,
    page: page,
    size: size,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty &&
      response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'DataPageGeOrderHistorySchema',
    ) as DataPageGeOrderHistorySchema;
  }
  return null;
}