InteractionSchema class

Constructors

InteractionSchema({MapContentSchema? content, TransitionSchema? transition})
Returns a new InteractionSchema instance.

Properties

content MapContentSchema?
Content of the map.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transition TransitionSchema?
Transition to another map.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) InteractionSchema?
Returns a new InteractionSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<InteractionSchema>
mapFromJson(dynamic json) Map<String, InteractionSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<InteractionSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.