InventorySlot class

Constructors

InventorySlot({required int slot, required String code, required int quantity})
Returns a new InventorySlot instance.

Properties

code String
Item code.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
quantity int
Quantity in the slot.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slot int
Inventory slot identifier.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) InventorySlot?
Returns a new InventorySlot instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<InventorySlot>
mapFromJson(dynamic json) Map<String, InventorySlot>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<InventorySlot>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.