ItemType class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) ItemType?
listFromJson(dynamic json, {bool growable = false}) List<ItemType>

Constants

amulet → const ItemType
artifact → const ItemType
bag → const ItemType
bodyArmor → const ItemType
boots → const ItemType
consumable → const ItemType
currency → const ItemType
helmet → const ItemType
legArmor → const ItemType
resource → const ItemType
ring → const ItemType
rune → const ItemType
shield → const ItemType
utility → const ItemType
values → const List<ItemType>
List of all possible values in this ItemType.
weapon → const ItemType