ItemsApi class

Constructors

ItemsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllItemsItemsGet({String? name, int? minLevel, int? maxLevel, ItemType? type, CraftSkill? craftSkill, String? craftMaterial, int? page, int? size}) Future<StaticDataPageItemSchema?>
Get All Items
getAllItemsItemsGetWithHttpInfo({String? name, int? minLevel, int? maxLevel, ItemType? type, CraftSkill? craftSkill, String? craftMaterial, int? page, int? size}) Future<Response>
Get All Items
getItemItemsCodeGet(String code) Future<ItemResponseSchema?>
Get Item
getItemItemsCodeGetWithHttpInfo(String code) Future<Response>
Get Item
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited