LeaderboardApi class

Constructors

LeaderboardApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAccountsLeaderboardLeaderboardAccountsGet({AccountLeaderboardType? sort, String? name, int? page, int? size}) Future<DataPageAccountLeaderboardSchema?>
Get Accounts Leaderboard
getAccountsLeaderboardLeaderboardAccountsGetWithHttpInfo({AccountLeaderboardType? sort, String? name, int? page, int? size}) Future<Response>
Get Accounts Leaderboard
getCharactersLeaderboardLeaderboardCharactersGet({CharacterLeaderboardType? sort, String? name, int? page, int? size}) Future<DataPageCharacterLeaderboardSchema?>
Get Characters Leaderboard
getCharactersLeaderboardLeaderboardCharactersGetWithHttpInfo({CharacterLeaderboardType? sort, String? name, int? page, int? size}) Future<Response>
Get Characters Leaderboard
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited