LogSchema class

Constructors

LogSchema({required String character, required String account, required LogType type, required String description, required Object? content, required int cooldown, DateTime? cooldownExpiration, required DateTime createdAt})
Returns a new LogSchema instance.

Properties

account String
Account character.
getter/setter pair
character String
Character name.
getter/setter pair
content Object?
getter/setter pair
cooldown int
Cooldown in seconds.
getter/setter pair
cooldownExpiration DateTime?
Datetime of cooldown expiration.
getter/setter pair
createdAt DateTime
Datetime of creation.
getter/setter pair
description String
Description of action.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type LogType
Type of action.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) LogSchema?
Returns a new LogSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<LogSchema>
mapFromJson(dynamic json) Map<String, LogSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<LogSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.