LogType class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) LogType?
listFromJson(dynamic json, {bool growable = false}) List<LogType>

Constants

achievement → const LogType
buyBankExpansion → const LogType
buyGe → const LogType
buyNpc → const LogType
cancelGe → const LogType
changeSkin → const LogType
claimItem → const LogType
crafting → const LogType
createBuyOrderGe → const LogType
deleteCharacter → const LogType
deleteItem → const LogType
depositGold → const LogType
depositItem → const LogType
equip → const LogType
fight → const LogType
fillBuyOrderGe → const LogType
gathering → const LogType
giveGold → const LogType
giveItem → const LogType
movement → const LogType
multiFight → const LogType
newTask → const LogType
receiveGold → const LogType
receiveItem → const LogType
recycling → const LogType
rename → const LogType
rest → const LogType
sandboxGiveGold → const LogType
sandboxGiveItem → const LogType
sandboxGiveXp → const LogType
sandboxResetAccount → const LogType
sellGe → const LogType
sellNpc → const LogType
spawn → const LogType
taskCancelled → const LogType
taskCompleted → const LogType
taskExchange → const LogType
taskTrade → const LogType
transition → const LogType
unequip → const LogType
use → const LogType
values → const List<LogType>
List of all possible values in this LogType.
withdrawGold → const LogType
withdrawItem → const LogType