MapsApi class

Constructors

MapsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllMapsMapsGet({MapLayer? layer, MapContentType? contentType, String? contentCode, bool? hideBlockedMaps, int? page, int? size}) Future<StaticDataPageMapSchema?>
Get All Maps
getAllMapsMapsGetWithHttpInfo({MapLayer? layer, MapContentType? contentType, String? contentCode, bool? hideBlockedMaps, int? page, int? size}) Future<Response>
Get All Maps
getLayerMapsMapsLayerGet(MapLayer layer, {MapContentType? contentType, String? contentCode, bool? hideBlockedMaps, int? page, int? size}) Future<StaticDataPageMapSchema?>
Get Layer Maps
getLayerMapsMapsLayerGetWithHttpInfo(MapLayer layer, {MapContentType? contentType, String? contentCode, bool? hideBlockedMaps, int? page, int? size}) Future<Response>
Get Layer Maps
getMapByIdMapsIdMapIdGet(int mapId) Future<MapResponseSchema?>
Get Map By Id
getMapByIdMapsIdMapIdGetWithHttpInfo(int mapId) Future<Response>
Get Map By Id
getMapByPositionMapsLayerXYGet(MapLayer layer, int x, int y) Future<MapResponseSchema?>
Get Map By Position
getMapByPositionMapsLayerXYGetWithHttpInfo(MapLayer layer, int x, int y) Future<Response>
Get Map By Position
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited