getAllMapsMapsGet method
Get All Maps
Fetch maps details.
Parameters:
-
MapLayer layer: Filter maps by layer.
-
MapContentType contentType: Type of maps.
-
String contentCode: Content code on the map.
-
bool hideBlockedMaps: When true, excludes maps with access_type 'blocked' from the results.
-
bool hideEvent: When true, does not overlay active events on maps.
-
bool transition: Filter maps by transition. True returns only maps with transitions, False returns only maps without.
-
int page: Page number
-
int size: Page size
Implementation
Future<StaticDataPageMapSchema?> getAllMapsMapsGet({
MapLayer? layer,
MapContentType? contentType,
String? contentCode,
bool? hideBlockedMaps,
bool? hideEvent,
bool? transition,
int? page,
int? size,
Future<void>? abortTrigger,
}) async {
final response = await getAllMapsMapsGetWithHttpInfo(
layer: layer,
contentType: contentType,
contentCode: contentCode,
hideBlockedMaps: hideBlockedMaps,
hideEvent: hideEvent,
transition: transition,
page: page,
size: size,
abortTrigger: abortTrigger,
);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty &&
response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(
await _decodeBodyBytes(response),
'StaticDataPageMapSchema',
) as StaticDataPageMapSchema;
}
return null;
}