drops property
Monster drops. This is a list of items that the monster drops after killing the monster.
Implementation
List<DropRateSchema> drops;
Monster drops. This is a list of items that the monster drops after killing the monster.
List<DropRateSchema> drops;