MonstersApi class

Constructors

MonstersApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllMonstersMonstersGet({String? name, int? minLevel, int? maxLevel, String? drop, int? page, int? size}) Future<StaticDataPageMonsterSchema?>
Get All Monsters
getAllMonstersMonstersGetWithHttpInfo({String? name, int? minLevel, int? maxLevel, String? drop, int? page, int? size}) Future<Response>
Get All Monsters
getMonsterMonstersCodeGet(String code) Future<MonsterResponseSchema?>
Get Monster
getMonsterMonstersCodeGetWithHttpInfo(String code) Future<Response>
Get Monster
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited