MyAccountApi class

Constructors

MyAccountApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

changePasswordMyChangePasswordPost(ChangePassword changePassword) Future<ResponseSchema?>
Change Password
changePasswordMyChangePasswordPostWithHttpInfo(ChangePassword changePassword) Future<Response>
Change Password
getAccountDetailsMyDetailsGet() Future<MyAccountDetailsSchema?>
Get Account Details
getAccountDetailsMyDetailsGetWithHttpInfo() Future<Response>
Get Account Details
getBankDetailsMyBankGet() Future<BankResponseSchema?>
Get Bank Details
getBankDetailsMyBankGetWithHttpInfo() Future<Response>
Get Bank Details
getBankItemsMyBankItemsGet({String? itemCode, int? page, int? size}) Future<DataPageSimpleItemSchema?>
Get Bank Items
getBankItemsMyBankItemsGetWithHttpInfo({String? itemCode, int? page, int? size}) Future<Response>
Get Bank Items
getGeHistoryMyGrandexchangeHistoryGet({String? id, String? code, int? page, int? size}) Future<DataPageGeOrderHistorySchema?>
Get Ge History
getGeHistoryMyGrandexchangeHistoryGetWithHttpInfo({String? id, String? code, int? page, int? size}) Future<Response>
Get Ge History
getGeOrdersMyGrandexchangeOrdersGet({String? code, GEOrderType? type, int? page, int? size}) Future<DataPageGEOrderSchema?>
Get Ge Orders
getGeOrdersMyGrandexchangeOrdersGetWithHttpInfo({String? code, GEOrderType? type, int? page, int? size}) Future<Response>
Get Ge Orders
getPendingItemsMyPendingItemsGet({int? page, int? size}) Future<DataPagePendingItemSchema?>
Get Pending Items
getPendingItemsMyPendingItemsGetWithHttpInfo({int? page, int? size}) Future<Response>
Get Pending Items
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited