buySubscriptionMySubscribeStripePost method

Future<CheckoutResponseWrapperSchema?> buySubscriptionMySubscribeStripePost(
  1. SubscribeRequestSchema subscribeRequestSchema, {
  2. Future<void>? abortTrigger,
})

Subscribe with Stripe

Subscribe to become a member and unlock the benefits tied to your selected plan. You will receive a secure Stripe checkout URL to complete the payment.

Parameters:

Implementation

Future<CheckoutResponseWrapperSchema?> buySubscriptionMySubscribeStripePost(
  SubscribeRequestSchema subscribeRequestSchema, {
  Future<void>? abortTrigger,
}) async {
  final response = await buySubscriptionMySubscribeStripePostWithHttpInfo(
    subscribeRequestSchema,
    abortTrigger: abortTrigger,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty &&
      response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'CheckoutResponseWrapperSchema',
    ) as CheckoutResponseWrapperSchema;
  }
  return null;
}