cancelSubscriptionMySubscribeCancelPost method

Future<ResponseSchema?> cancelSubscriptionMySubscribeCancelPost({
  1. Future<void>? abortTrigger,
})

Cancel Subscription

Cancel subscription at the end of the current billing period.

Implementation

Future<ResponseSchema?> cancelSubscriptionMySubscribeCancelPost({
  Future<void>? abortTrigger,
}) async {
  final response = await cancelSubscriptionMySubscribeCancelPostWithHttpInfo(
    abortTrigger: abortTrigger,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty &&
      response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'ResponseSchema',
    ) as ResponseSchema;
  }
  return null;
}