MyAccountDetails class

Constructors

MyAccountDetails({required String username, required String email, required bool member, DateTime? memberExpiration, required AccountStatus status, List<String> badges = const [], List<String> skins = const [], required int gems, required int eventToken, required int achievementsPoints, required bool banned, String? banReason})
Returns a new MyAccountDetails instance.

Properties

achievementsPoints int
Achievement points.
getter/setter pair
badges List<String>
Account badges.
getter/setter pair
banned bool
Banned.
getter/setter pair
banReason String?
Ban reason.
getter/setter pair
email String
Email.
getter/setter pair
eventToken int
Event tokens for spawning events.
getter/setter pair
gems int
Gems.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
member bool
Member status.
getter/setter pair
memberExpiration DateTime?
Member expiration date.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skins List<String>
Skins owned.
getter/setter pair
status AccountStatus
Account status.
getter/setter pair
username String
Username.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) MyAccountDetails?
Returns a new MyAccountDetails instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<MyAccountDetails>
mapFromJson(dynamic json) Map<String, MyAccountDetails>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<MyAccountDetails>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.