MyCharactersApi class

Constructors

MyCharactersApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

actionAcceptNewTaskMyNameActionTaskNewPost(String name) Future<TaskResponseSchema?>
Action Accept New Task
actionAcceptNewTaskMyNameActionTaskNewPostWithHttpInfo(String name) Future<Response>
Action Accept New Task
actionBuyBankExpansionMyNameActionBankBuyExpansionPost(String name) Future<BankExtensionTransactionResponseSchema?>
Action Buy Bank Expansion
actionBuyBankExpansionMyNameActionBankBuyExpansionPostWithHttpInfo(String name) Future<Response>
Action Buy Bank Expansion
actionChangeSkinMyNameActionChangeSkinPost(String name, ChangeSkinCharacterSchema changeSkinCharacterSchema) Future<ChangeSkinResponseSchema?>
Action Change Skin
actionChangeSkinMyNameActionChangeSkinPostWithHttpInfo(String name, ChangeSkinCharacterSchema changeSkinCharacterSchema) Future<Response>
Action Change Skin
actionClaimPendingItemMyNameActionClaimItemIdPost(String name, String id) Future<ClaimPendingItemResponseSchema?>
Action Claim Pending Item
actionClaimPendingItemMyNameActionClaimItemIdPostWithHttpInfo(String name, String id) Future<Response>
Action Claim Pending Item
actionCompleteTaskMyNameActionTaskCompletePost(String name) Future<RewardDataResponseSchema?>
Action Complete Task
actionCompleteTaskMyNameActionTaskCompletePostWithHttpInfo(String name) Future<Response>
Action Complete Task
actionCraftingMyNameActionCraftingPost(String name, CraftingSchema craftingSchema) Future<SkillResponseSchema?>
Action Crafting
actionCraftingMyNameActionCraftingPostWithHttpInfo(String name, CraftingSchema craftingSchema) Future<Response>
Action Crafting
actionDeleteItemMyNameActionDeletePost(String name, SimpleItemSchema simpleItemSchema) Future<DeleteItemResponseSchema?>
Action Delete Item
actionDeleteItemMyNameActionDeletePostWithHttpInfo(String name, SimpleItemSchema simpleItemSchema) Future<Response>
Action Delete Item
actionDepositBankGoldMyNameActionBankDepositGoldPost(String name, DepositWithdrawGoldSchema depositWithdrawGoldSchema) Future<BankGoldTransactionResponseSchema?>
Action Deposit Bank Gold
actionDepositBankGoldMyNameActionBankDepositGoldPostWithHttpInfo(String name, DepositWithdrawGoldSchema depositWithdrawGoldSchema) Future<Response>
Action Deposit Bank Gold
actionDepositBankItemMyNameActionBankDepositItemPost(String name, List<SimpleItemSchema> simpleItemSchema) Future<BankItemTransactionResponseSchema?>
Action Deposit Bank Item
actionDepositBankItemMyNameActionBankDepositItemPostWithHttpInfo(String name, List<SimpleItemSchema> simpleItemSchema) Future<Response>
Action Deposit Bank Item
actionEquipItemMyNameActionEquipPost(String name, EquipSchema equipSchema) Future<EquipmentResponseSchema?>
Action Equip Item
actionEquipItemMyNameActionEquipPostWithHttpInfo(String name, EquipSchema equipSchema) Future<Response>
Action Equip Item
actionFightMyNameActionFightPost(String name, {FightRequestSchema? fightRequestSchema}) Future<CharacterFightResponseSchema?>
Action Fight
actionFightMyNameActionFightPostWithHttpInfo(String name, {FightRequestSchema? fightRequestSchema}) Future<Response>
Action Fight
actionGatheringMyNameActionGatheringPost(String name) Future<SkillResponseSchema?>
Action Gathering
actionGatheringMyNameActionGatheringPostWithHttpInfo(String name) Future<Response>
Action Gathering
actionGeBuyItemMyNameActionGrandexchangeBuyPost(String name, GEBuyOrderSchema gEBuyOrderSchema) Future<GETransactionResponseSchema?>
Action Ge Buy Item
actionGeBuyItemMyNameActionGrandexchangeBuyPostWithHttpInfo(String name, GEBuyOrderSchema gEBuyOrderSchema) Future<Response>
Action Ge Buy Item
actionGeCancelOrderMyNameActionGrandexchangeCancelPost(String name, GECancelOrderSchema gECancelOrderSchema) Future<GETransactionResponseSchema?>
Action Ge Cancel Order
actionGeCancelOrderMyNameActionGrandexchangeCancelPostWithHttpInfo(String name, GECancelOrderSchema gECancelOrderSchema) Future<Response>
Action Ge Cancel Order
actionGeCreateBuyOrderMyNameActionGrandexchangeCreateBuyOrderPost(String name, GEBuyOrderCreationSchema gEBuyOrderCreationSchema) Future<GECreateOrderTransactionResponseSchema?>
Action Ge Create Buy Order
actionGeCreateBuyOrderMyNameActionGrandexchangeCreateBuyOrderPostWithHttpInfo(String name, GEBuyOrderCreationSchema gEBuyOrderCreationSchema) Future<Response>
Action Ge Create Buy Order
actionGeCreateSellOrderMyNameActionGrandexchangeCreateSellOrderPost(String name, GEOrderCreationrSchema gEOrderCreationrSchema) Future<GECreateOrderTransactionResponseSchema?>
Action Ge Create Sell Order
actionGeCreateSellOrderMyNameActionGrandexchangeCreateSellOrderPostWithHttpInfo(String name, GEOrderCreationrSchema gEOrderCreationrSchema) Future<Response>
Action Ge Create Sell Order
actionGeFillMyNameActionGrandexchangeFillPost(String name, GEFillBuyOrderSchema gEFillBuyOrderSchema) Future<GETransactionResponseSchema?>
Action Ge Fill
actionGeFillMyNameActionGrandexchangeFillPostWithHttpInfo(String name, GEFillBuyOrderSchema gEFillBuyOrderSchema) Future<Response>
Action Ge Fill
actionGiveGoldMyNameActionGiveGoldPost(String name, GiveGoldSchema giveGoldSchema) Future<GiveGoldResponseSchema?>
Action Give Gold
actionGiveGoldMyNameActionGiveGoldPostWithHttpInfo(String name, GiveGoldSchema giveGoldSchema) Future<Response>
Action Give Gold
actionGiveItemsMyNameActionGiveItemPost(String name, GiveItemsSchema giveItemsSchema) Future<GiveItemResponseSchema?>
Action Give Items
actionGiveItemsMyNameActionGiveItemPostWithHttpInfo(String name, GiveItemsSchema giveItemsSchema) Future<Response>
Action Give Items
actionMoveMyNameActionMovePost(String name, DestinationSchema destinationSchema) Future<CharacterMovementResponseSchema?>
Action Move
actionMoveMyNameActionMovePostWithHttpInfo(String name, DestinationSchema destinationSchema) Future<Response>
Action Move
actionNpcBuyItemMyNameActionNpcBuyPost(String name, NpcMerchantBuySchema npcMerchantBuySchema) Future<NpcMerchantTransactionResponseSchema?>
Action Npc Buy Item
actionNpcBuyItemMyNameActionNpcBuyPostWithHttpInfo(String name, NpcMerchantBuySchema npcMerchantBuySchema) Future<Response>
Action Npc Buy Item
actionNpcSellItemMyNameActionNpcSellPost(String name, NpcMerchantBuySchema npcMerchantBuySchema) Future<NpcMerchantTransactionResponseSchema?>
Action Npc Sell Item
actionNpcSellItemMyNameActionNpcSellPostWithHttpInfo(String name, NpcMerchantBuySchema npcMerchantBuySchema) Future<Response>
Action Npc Sell Item
actionRecyclingMyNameActionRecyclingPost(String name, RecyclingSchema recyclingSchema) Future<RecyclingResponseSchema?>
Action Recycling
actionRecyclingMyNameActionRecyclingPostWithHttpInfo(String name, RecyclingSchema recyclingSchema) Future<Response>
Action Recycling
actionRestMyNameActionRestPost(String name) Future<CharacterRestResponseSchema?>
Action Rest
actionRestMyNameActionRestPostWithHttpInfo(String name) Future<Response>
Action Rest
actionTaskCancelMyNameActionTaskCancelPost(String name) Future<TaskCancelledResponseSchema?>
Action Task Cancel
actionTaskCancelMyNameActionTaskCancelPostWithHttpInfo(String name) Future<Response>
Action Task Cancel
actionTaskExchangeMyNameActionTaskExchangePost(String name) Future<RewardDataResponseSchema?>
Action Task Exchange
actionTaskExchangeMyNameActionTaskExchangePostWithHttpInfo(String name) Future<Response>
Action Task Exchange
actionTaskTradeMyNameActionTaskTradePost(String name, SimpleItemSchema simpleItemSchema) Future<TaskTradeResponseSchema?>
Action Task Trade
actionTaskTradeMyNameActionTaskTradePostWithHttpInfo(String name, SimpleItemSchema simpleItemSchema) Future<Response>
Action Task Trade
actionTransitionMyNameActionTransitionPost(String name) Future<CharacterTransitionResponseSchema?>
Action Transition
actionTransitionMyNameActionTransitionPostWithHttpInfo(String name) Future<Response>
Action Transition
actionUnequipItemMyNameActionUnequipPost(String name, UnequipSchema unequipSchema) Future<EquipmentResponseSchema?>
Action Unequip Item
actionUnequipItemMyNameActionUnequipPostWithHttpInfo(String name, UnequipSchema unequipSchema) Future<Response>
Action Unequip Item
actionUseItemMyNameActionUsePost(String name, SimpleItemSchema simpleItemSchema) Future<UseItemResponseSchema?>
Action Use Item
actionUseItemMyNameActionUsePostWithHttpInfo(String name, SimpleItemSchema simpleItemSchema) Future<Response>
Action Use Item
actionWithdrawBankGoldMyNameActionBankWithdrawGoldPost(String name, DepositWithdrawGoldSchema depositWithdrawGoldSchema) Future<BankGoldTransactionResponseSchema?>
Action Withdraw Bank Gold
actionWithdrawBankGoldMyNameActionBankWithdrawGoldPostWithHttpInfo(String name, DepositWithdrawGoldSchema depositWithdrawGoldSchema) Future<Response>
Action Withdraw Bank Gold
actionWithdrawBankItemMyNameActionBankWithdrawItemPost(String name, List<SimpleItemSchema> simpleItemSchema) Future<BankItemTransactionResponseSchema?>
Action Withdraw Bank Item
actionWithdrawBankItemMyNameActionBankWithdrawItemPostWithHttpInfo(String name, List<SimpleItemSchema> simpleItemSchema) Future<Response>
Action Withdraw Bank Item
getAllCharactersLogsMyLogsGet({int? page, int? size}) Future<DataPageLogSchema?>
Get All Characters Logs
getAllCharactersLogsMyLogsGetWithHttpInfo({int? page, int? size}) Future<Response>
Get All Characters Logs
getCharacterLogsMyLogsNameGet(String name, {int? page, int? size}) Future<DataPageLogSchema?>
Get Character Logs
getCharacterLogsMyLogsNameGetWithHttpInfo(String name, {int? page, int? size}) Future<Response>
Get Character Logs
getMyCharactersMyCharactersGet() Future<MyCharactersListSchema?>
Get My Characters
getMyCharactersMyCharactersGetWithHttpInfo() Future<Response>
Get My Characters
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited