actionFightMyNameActionFightPost method

Future<CharacterFightResponseSchema?> actionFightMyNameActionFightPost(
  1. String name, {
  2. FightRequestSchema? fightRequestSchema,
})

Action Fight

Start a fight against a monster on the character's map. Add participants for multi-character fights (up to 3 characters, only for boss).

Parameters:

Implementation

Future<CharacterFightResponseSchema?> actionFightMyNameActionFightPost(
  String name, {
  FightRequestSchema? fightRequestSchema,
}) async {
  final response = await actionFightMyNameActionFightPostWithHttpInfo(
    name,
    fightRequestSchema: fightRequestSchema,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty &&
      response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'CharacterFightResponseSchema',
    ) as CharacterFightResponseSchema;
  }
  return null;
}