actionGeCancelSellOrderMyNameActionGrandexchangeCancelPost method

Future<GETransactionResponseSchema?> actionGeCancelSellOrderMyNameActionGrandexchangeCancelPost(
  1. String name,
  2. GECancelOrderSchema gECancelOrderSchema
)

Action Ge Cancel Sell Order

Cancel a sell order at the Grand Exchange on the character's map.

Parameters:

Implementation

Future<GETransactionResponseSchema?>
    actionGeCancelSellOrderMyNameActionGrandexchangeCancelPost(
  String name,
  GECancelOrderSchema gECancelOrderSchema,
) async {
  final response =
      await actionGeCancelSellOrderMyNameActionGrandexchangeCancelPostWithHttpInfo(
    name,
    gECancelOrderSchema,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty &&
      response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'GETransactionResponseSchema',
    ) as GETransactionResponseSchema;
  }
  return null;
}