actionGeCreateBuyOrderMyNameActionGrandexchangeCreateBuyOrderPost method

Future<GECreateOrderTransactionResponseSchema?> actionGeCreateBuyOrderMyNameActionGrandexchangeCreateBuyOrderPost(
  1. String name,
  2. GEBuyOrderCreationSchema gEBuyOrderCreationSchema
)

Action Ge Create Buy Order

Create a buy order at the Grand Exchange on the character's map. The total gold (price * quantity) is locked when creating the order. Other players can then sell items to fulfill your order. Items will be delivered to your pending items when the order is filled.

Parameters:

Implementation

Future<GECreateOrderTransactionResponseSchema?>
    actionGeCreateBuyOrderMyNameActionGrandexchangeCreateBuyOrderPost(
  String name,
  GEBuyOrderCreationSchema gEBuyOrderCreationSchema,
) async {
  final response =
      await actionGeCreateBuyOrderMyNameActionGrandexchangeCreateBuyOrderPostWithHttpInfo(
    name,
    gEBuyOrderCreationSchema,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty &&
      response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'GECreateOrderTransactionResponseSchema',
    ) as GECreateOrderTransactionResponseSchema;
  }
  return null;
}