actionGeCreateSellOrderMyNameActionGrandexchangeCreateSellOrderPost method
Future<GECreateOrderTransactionResponseSchema?>
actionGeCreateSellOrderMyNameActionGrandexchangeCreateSellOrderPost(
- String name,
- GEOrderCreationrSchema gEOrderCreationrSchema
Action Ge Create Sell Order
Create a sell order at the Grand Exchange on the character's map.
Parameters:
-
String name (required): Name of your character.
-
GEOrderCreationrSchema gEOrderCreationrSchema (required):
Implementation
Future<GECreateOrderTransactionResponseSchema?>
actionGeCreateSellOrderMyNameActionGrandexchangeCreateSellOrderPost(
String name,
GEOrderCreationrSchema gEOrderCreationrSchema,
) async {
final response =
await actionGeCreateSellOrderMyNameActionGrandexchangeCreateSellOrderPostWithHttpInfo(
name,
gEOrderCreationrSchema,
);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty &&
response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(
await _decodeBodyBytes(response),
'GECreateOrderTransactionResponseSchema',
) as GECreateOrderTransactionResponseSchema;
}
return null;
}