actionGeFillMyNameActionGrandexchangeFillPost method
Future<GETransactionResponseSchema?>
actionGeFillMyNameActionGrandexchangeFillPost(
- String name,
- GEFillBuyOrderSchema gEFillBuyOrderSchema
Action Ge Fill
Sell items to an existing buy order at the Grand Exchange on the character's map. You will receive the gold immediately. The buyer will receive the items in their pending items.
Parameters:
-
String name (required): Name of your character.
-
GEFillBuyOrderSchema gEFillBuyOrderSchema (required):
Implementation
Future<GETransactionResponseSchema?>
actionGeFillMyNameActionGrandexchangeFillPost(
String name,
GEFillBuyOrderSchema gEFillBuyOrderSchema,
) async {
final response =
await actionGeFillMyNameActionGrandexchangeFillPostWithHttpInfo(
name,
gEFillBuyOrderSchema,
);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty &&
response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(
await _decodeBodyBytes(response),
'GETransactionResponseSchema',
) as GETransactionResponseSchema;
}
return null;
}