actionGiveItemsMyNameActionGiveItemPostWithHttpInfo method

Future<Response> actionGiveItemsMyNameActionGiveItemPostWithHttpInfo(
  1. String name,
  2. GiveItemsSchema giveItemsSchema
)

Action Give Items

Give items to another character in your account on the same map. The cooldown will be 3 seconds multiplied by the number of different items given.

Note: This method returns the HTTP Response.

Parameters:

Implementation

Future<Response> actionGiveItemsMyNameActionGiveItemPostWithHttpInfo(
  String name,
  GiveItemsSchema giveItemsSchema,
) async {
  // ignore: prefer_const_declarations
  final path = r'/my/{name}/action/give/item'.replaceAll('{name}', name);

  // ignore: prefer_final_locals
  Object? postBody = giveItemsSchema;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

  const contentTypes = <String>['application/json'];

  return apiClient.invokeAPI(
    path,
    'POST',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes.first,
  );
}