actionMoveMyNameActionMovePost method

Future<CharacterMovementResponseSchema?> actionMoveMyNameActionMovePost(
  1. String name,
  2. DestinationSchema destinationSchema
)

Action Move

Moves a character on the map using either the map's ID or X and Y position. Provide either 'map_id' or both 'x' and 'y' coordinates in the request body.

Parameters:

Implementation

Future<CharacterMovementResponseSchema?> actionMoveMyNameActionMovePost(
  String name,
  DestinationSchema destinationSchema,
) async {
  final response = await actionMoveMyNameActionMovePostWithHttpInfo(
    name,
    destinationSchema,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty &&
      response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'CharacterMovementResponseSchema',
    ) as CharacterMovementResponseSchema;
  }
  return null;
}