actionRecyclingMyNameActionRecyclingPost method

Future<RecyclingResponseSchema?> actionRecyclingMyNameActionRecyclingPost(
  1. String name,
  2. RecyclingSchema recyclingSchema
)

Action Recycling

Recycling an item. The character must be on a map with a workshop (only for equipments and weapons).

Parameters:

Implementation

Future<RecyclingResponseSchema?> actionRecyclingMyNameActionRecyclingPost(
  String name,
  RecyclingSchema recyclingSchema,
) async {
  final response = await actionRecyclingMyNameActionRecyclingPostWithHttpInfo(
    name,
    recyclingSchema,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty &&
      response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'RecyclingResponseSchema',
    ) as RecyclingResponseSchema;
  }
  return null;
}