actionTransitionMyNameActionTransitionPost method

Future<CharacterTransitionResponseSchema?> actionTransitionMyNameActionTransitionPost(
  1. String name
)

Action Transition

Execute a transition from the current map to another layer. The character must be on a map that has a transition available.

Parameters:

  • String name (required): Name of your character.

Implementation

Future<CharacterTransitionResponseSchema?>
    actionTransitionMyNameActionTransitionPost(
  String name,
) async {
  final response =
      await actionTransitionMyNameActionTransitionPostWithHttpInfo(
    name,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty &&
      response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'CharacterTransitionResponseSchema',
    ) as CharacterTransitionResponseSchema;
  }
  return null;
}