actionTransitionMyNameActionTransitionPostWithHttpInfo method
Action Transition
Execute a transition from the current map to another layer. The character must be on a map that has a transition available.
Note: This method returns the HTTP Response.
Parameters:
- String name (required): Name of your character.
Implementation
Future<Response> actionTransitionMyNameActionTransitionPostWithHttpInfo(
String name,
) async {
// ignore: prefer_const_declarations
final path = r'/my/{name}/action/transition'.replaceAll('{name}', name);
// ignore: prefer_final_locals
Object? postBody;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
const contentTypes = <String>[];
return apiClient.invokeAPI(
path,
'POST',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes.first,
);
}