actionWithdrawBankItemMyNameActionBankWithdrawItemPost method

Future<BankItemTransactionResponseSchema?> actionWithdrawBankItemMyNameActionBankWithdrawItemPost(
  1. String name,
  2. List<SimpleItemSchema> simpleItemSchema
)

Action Withdraw Bank Item

Take items from your bank and put them in the character's inventory. The cooldown will be 3 seconds multiplied by the number of different items withdrawn.

Parameters:

Implementation

Future<BankItemTransactionResponseSchema?>
    actionWithdrawBankItemMyNameActionBankWithdrawItemPost(
  String name,
  List<SimpleItemSchema> simpleItemSchema,
) async {
  final response =
      await actionWithdrawBankItemMyNameActionBankWithdrawItemPostWithHttpInfo(
    name,
    simpleItemSchema,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty &&
      response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'BankItemTransactionResponseSchema',
    ) as BankItemTransactionResponseSchema;
  }
  return null;
}