actionWithdrawBankItemMyNameActionBankWithdrawItemPostWithHttpInfo method
Future<Response>
actionWithdrawBankItemMyNameActionBankWithdrawItemPostWithHttpInfo(
- String name,
- List<
SimpleItemSchema> simpleItemSchema
Action Withdraw Bank Item
Take items from your bank and put them in the character's inventory. The cooldown will be 3 seconds multiplied by the number of different items withdrawn.
Note: This method returns the HTTP Response.
Parameters:
-
String name (required): Name of your character.
-
List<SimpleItemSchema> simpleItemSchema (required):
Implementation
Future<Response>
actionWithdrawBankItemMyNameActionBankWithdrawItemPostWithHttpInfo(
String name,
List<SimpleItemSchema> simpleItemSchema,
) async {
// ignore: prefer_const_declarations
final path =
r'/my/{name}/action/bank/withdraw/item'.replaceAll('{name}', name);
// ignore: prefer_final_locals
Object? postBody = simpleItemSchema;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
const contentTypes = <String>['application/json'];
return apiClient.invokeAPI(
path,
'POST',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes.first,
);
}