getMyCharactersMyCharactersGet method
- @Deprecated('Use accounts/{account}/characters')
Get My Characters
List of your characters. This endpoint is deprecated and will be removed in a future version. Please use accounts/{account}/characters.
Implementation
@Deprecated('Use accounts/{account}/characters')
Future<MyCharactersListSchema?> getMyCharactersMyCharactersGet() async {
final response = await getMyCharactersMyCharactersGetWithHttpInfo();
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(
await _decodeBodyBytes(response),
'MyCharactersListSchema',
) as MyCharactersListSchema;
}
return null;
}