NPCItem class

Constructors

NPCItem({required String code, required String npc, required String currency, int? buyPrice, int? sellPrice})
Returns a new NPCItem instance.

Properties

buyPrice int?
Price to buy the item.
getter/setter pair
code String
The code of the NPC. This is the NPC's unique identifier (ID).
getter/setter pair
currency String
Currency used to buy/sell the item. If it's not gold, it's the item code.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
npc String
Code of the NPC that sells/buys the item.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sellPrice int?
Price to sell the item.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) NPCItem?
Returns a new NPCItem instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<NPCItem>
mapFromJson(dynamic json) Map<String, NPCItem>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<NPCItem>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.