NPCsApi class

Constructors

NPCsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllNpcsItemsNpcsItemsGet({String? code, String? npc, String? currency, int? page, int? size}) Future<StaticDataPageNPCItem?>
Get All Npcs Items
getAllNpcsItemsNpcsItemsGetWithHttpInfo({String? code, String? npc, String? currency, int? page, int? size}) Future<Response>
Get All Npcs Items
getAllNpcsNpcsDetailsGet({String? name, NPCType? type, int? page, int? size}) Future<StaticDataPageNPCSchema?>
Get All Npcs
getAllNpcsNpcsDetailsGetWithHttpInfo({String? name, NPCType? type, int? page, int? size}) Future<Response>
Get All Npcs
getNpcItemsNpcsItemsCodeGet(String code, {int? page, int? size}) Future<StaticDataPageNPCItem?>
Get Npc Items
getNpcItemsNpcsItemsCodeGetWithHttpInfo(String code, {int? page, int? size}) Future<Response>
Get Npc Items
getNpcNpcsDetailsCodeGet(String code) Future<NPCResponseSchema?>
Get Npc
getNpcNpcsDetailsCodeGetWithHttpInfo(String code) Future<Response>
Get Npc
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited