getNpcItemsNpcsItemsCodeGet method

Future<StaticDataPageNPCItem?> getNpcItemsNpcsItemsCodeGet(
  1. String code, {
  2. int? page,
  3. int? size,
})

Get Npc Items

Retrieve the items list of a NPC. If the NPC has items to buy, sell or trade, they will be displayed.

Parameters:

  • String code (required): The code of the NPC.

  • int page: Page number

  • int size: Page size

Implementation

Future<StaticDataPageNPCItem?> getNpcItemsNpcsItemsCodeGet(
  String code, {
  int? page,
  int? size,
}) async {
  final response = await getNpcItemsNpcsItemsCodeGetWithHttpInfo(
    code,
    page: page,
    size: size,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty &&
      response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'StaticDataPageNPCItem',
    ) as StaticDataPageNPCItem;
  }
  return null;
}