PasswordResetConfirmSchema class
Constructors
- PasswordResetConfirmSchema({required String token, required String newPassword})
- Returns a new PasswordResetConfirmSchema instance.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- newPassword ↔ String
-
Your new password.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token ↔ String
-
Password reset token.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → PasswordResetConfirmSchema? -
Returns a new PasswordResetConfirmSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< PasswordResetConfirmSchema> -
mapFromJson(
dynamic json) → Map< String, PasswordResetConfirmSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< PasswordResetConfirmSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.