PendingItemSource class

Source types for pending items.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) PendingItemSource?
listFromJson(dynamic json, {bool growable = false}) List<PendingItemSource>

Constants

achievement → const PendingItemSource
admin → const PendingItemSource
event → const PendingItemSource
grandExchange → const PendingItemSource
other → const PendingItemSource
values → const List<PendingItemSource>
List of all possible values in this PendingItemSource.