PurchaseHistorySchema class

Constructors

PurchaseHistorySchema({required PurchaseType type, required String description, required int amount, int gemsCredited = 0, required DateTime createdAt})
Returns a new PurchaseHistorySchema instance.

Properties

amount int
Amount in cents.
getter/setter pair
createdAt DateTime
When the purchase was made.
getter/setter pair
description String
Description of the purchase.
getter/setter pair
gemsCredited int
Gems credited from this purchase.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type PurchaseType
Type of purchase.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) PurchaseHistorySchema?
Returns a new PurchaseHistorySchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<PurchaseHistorySchema>
mapFromJson(dynamic json) Map<String, PurchaseHistorySchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<PurchaseHistorySchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.