RaidDamageRewardSchema class
Constructors
-
RaidDamageRewardSchema({required int damagePerReward, int? maxRewards, List<
SimpleItemSchema> items = const []}) - Returns a new RaidDamageRewardSchema instance.
Properties
- damagePerReward ↔ int
-
Damage required per reward instance.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
-
items
↔ List<
SimpleItemSchema> -
Items granted per reward instance.
getter/setter pair
- maxRewards ↔ int?
-
Maximum number of times this reward can be granted. Null means no cap.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → RaidDamageRewardSchema? -
Returns a new RaidDamageRewardSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< RaidDamageRewardSchema> -
mapFromJson(
dynamic json) → Map< String, RaidDamageRewardSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< RaidDamageRewardSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.