RaidInstanceSchema class

Constructors

RaidInstanceSchema({required DateTime startsAt, required DateTime endsAt, required RaidStatus status, required int totalHp, required int remainingHp, int participantCount = 0, DateTime? endedAt, RaidInstanceResult? result, DateTime? rewardsDistributedAt})
Returns a new RaidInstanceSchema instance.

Properties

endedAt DateTime?
Datetime when this raid instance actually ended.
getter/setter pair
endsAt DateTime
Weekly raid planned closing datetime in UTC.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
participantCount int
Number of accounts that contributed during this raid instance.
getter/setter pair
remainingHp int
Remaining shared HP pool for this raid instance.
getter/setter pair
result RaidInstanceResult?
Final result for this raid instance.
getter/setter pair
rewardsDistributedAt DateTime?
Datetime when rewards were distributed for this raid instance.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startsAt DateTime
Weekly raid opening datetime in UTC.
getter/setter pair
status RaidStatus
Current status of this weekly raid instance.
getter/setter pair
totalHp int
Shared HP pool when this raid instance starts.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) RaidInstanceSchema?
Returns a new RaidInstanceSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<RaidInstanceSchema>
mapFromJson(dynamic json) Map<String, RaidInstanceSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<RaidInstanceSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.