RaidLeaderboardEntrySchema class

Constructors

RaidLeaderboardEntrySchema({required int position, required String account, required int points})
Returns a new RaidLeaderboardEntrySchema instance.

Properties

account String
Account name.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
points int
Points earned for this raid instance.
getter/setter pair
position int
Leaderboard position.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) RaidLeaderboardEntrySchema?
Returns a new RaidLeaderboardEntrySchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<RaidLeaderboardEntrySchema>
mapFromJson(dynamic json) Map<String, RaidLeaderboardEntrySchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<RaidLeaderboardEntrySchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.