RaidRewardsSchema class

Constructors

RaidRewardsSchema({List<RaidDamageRewardSchema> damageRewards = const [], List<RaidRankRewardSchema> leaderboard = const []})
Returns a new RaidRewardsSchema instance.

Properties

damageRewards List<RaidDamageRewardSchema>
Items granted based on cumulative damage dealt.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
leaderboard List<RaidRankRewardSchema>
Items granted based on leaderboard rank.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) RaidRewardsSchema?
Returns a new RaidRewardsSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<RaidRewardsSchema>
mapFromJson(dynamic json) Map<String, RaidRewardsSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<RaidRewardsSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.