RaidScheduleSchema class
Constructors
-
RaidScheduleSchema({List<
RaidWeekday> weekdays = const [], int startHourUtc = 0, int startMinuteUtc = 0, int durationHours = 24}) - Returns a new RaidScheduleSchema instance.
Properties
- durationHours ↔ int
-
Maximum raid duration in hours.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startHourUtc ↔ int
-
UTC hour when the raid opens.
getter/setter pair
- startMinuteUtc ↔ int
-
UTC minute when the raid opens.
getter/setter pair
-
weekdays
↔ List<
RaidWeekday> -
UTC weekdays when the raid opens.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → RaidScheduleSchema? -
Returns a new RaidScheduleSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< RaidScheduleSchema> -
mapFromJson(
dynamic json) → Map< String, RaidScheduleSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< RaidScheduleSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.