participantCount property
Number of distinct accounts that contributed to the active or latest raid instance.
Minimum value: 0
Implementation
int participantCount;
Number of distinct accounts that contributed to the active or latest raid instance.
Minimum value: 0
int participantCount;