RateLimitWindowSchema class
Constructors
- RateLimitWindowSchema({required int limit, required int remaining, required DateTime reset})
- Returns a new RateLimitWindowSchema instance.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit ↔ int
-
Maximum requests allowed in this window.
getter/setter pair
- remaining ↔ int
-
Remaining requests in the current window.
getter/setter pair
- reset ↔ DateTime
-
UTC datetime when the window resets.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → RateLimitWindowSchema? -
Returns a new RateLimitWindowSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< RateLimitWindowSchema> -
mapFromJson(
dynamic json) → Map< String, RateLimitWindowSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< RateLimitWindowSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.