RateLimitsDataSchema class

Constructors

RateLimitsDataSchema({required RateLimitScopeSchema account, required RateLimitScopeSchema data, required RateLimitScopeSchema action, required RateLimitScopeSchema simulation, RateLimitScopeSchema? assistant})
Returns a new RateLimitsDataSchema instance.

Properties

account RateLimitScopeSchema
Rate limits for account endpoints.
getter/setter pair
action RateLimitScopeSchema
Rate limits for action endpoints.
getter/setter pair
assistant RateLimitScopeSchema?
Assistant daily usage. Only available for members.
getter/setter pair
data RateLimitScopeSchema
Rate limits for data endpoints.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simulation RateLimitScopeSchema
Rate limits for the fight simulation endpoint. Only available for members.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) RateLimitsDataSchema?
Returns a new RateLimitsDataSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<RateLimitsDataSchema>
mapFromJson(dynamic json) Map<String, RateLimitsDataSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<RateLimitsDataSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.