ResourcesApi class

Constructors

ResourcesApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllResourcesResourcesGet({int? minLevel, int? maxLevel, GatheringSkill? skill, String? drop, int? page, int? size}) Future<StaticDataPageResourceSchema?>
Get All Resources
getAllResourcesResourcesGetWithHttpInfo({int? minLevel, int? maxLevel, GatheringSkill? skill, String? drop, int? page, int? size}) Future<Response>
Get All Resources
getResourceResourcesCodeGet(String code) Future<ResourceResponseSchema?>
Get Resource
getResourceResourcesCodeGetWithHttpInfo(String code) Future<Response>
Get Resource
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited