RewardItemSchema class

Constructors

RewardItemSchema({required String code, required int quantity})
Returns a new RewardItemSchema instance.

Properties

code String
Item code.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
quantity int
Item quantity.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) RewardItemSchema?
Returns a new RewardItemSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<RewardItemSchema>
mapFromJson(dynamic json) Map<String, RewardItemSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<RewardItemSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.