SandboxApi class

Constructors

SandboxApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearCooldownSandboxClearCooldownPost(SandboxCharacterActionSchema sandboxCharacterActionSchema, {Future<void>? abortTrigger}) Future<SandboxResponseSchema?>
Clear Cooldown
clearCooldownSandboxClearCooldownPostWithHttpInfo(SandboxCharacterActionSchema sandboxCharacterActionSchema, {Future<void>? abortTrigger}) Future<Response>
Clear Cooldown
giveGoldSandboxGiveGoldPost(GiveGoldSchema giveGoldSchema, {Future<void>? abortTrigger}) Future<SandboxGiveGoldResponseSchema?>
Give Gold
giveGoldSandboxGiveGoldPostWithHttpInfo(GiveGoldSchema giveGoldSchema, {Future<void>? abortTrigger}) Future<Response>
Give Gold
giveItemSandboxGiveItemPost(SandboxGiveItemSchema sandboxGiveItemSchema, {Future<void>? abortTrigger}) Future<SandboxGiveItemResponseSchema?>
Give Item
giveItemSandboxGiveItemPostWithHttpInfo(SandboxGiveItemSchema sandboxGiveItemSchema, {Future<void>? abortTrigger}) Future<Response>
Give Item
giveXpSandboxGiveXpPost(SandboxGiveXPSchema sandboxGiveXPSchema, {Future<void>? abortTrigger}) Future<SandboxGiveXPResponseSchema?>
Give Xp
giveXpSandboxGiveXpPostWithHttpInfo(SandboxGiveXPSchema sandboxGiveXPSchema, {Future<void>? abortTrigger}) Future<Response>
Give Xp
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetAccountSandboxResetAccountPost({Future<void>? abortTrigger}) Future<ResponseSchema?>
Reset Account
resetAccountSandboxResetAccountPostWithHttpInfo({Future<void>? abortTrigger}) Future<Response>
Reset Account
spawnEventSandboxSpawnEventPost(SpawnEventRequestSchema spawnEventRequestSchema, {Future<void>? abortTrigger}) Future<ActiveEventResponseSchema?>
Spawn Event
spawnEventSandboxSpawnEventPostWithHttpInfo(SpawnEventRequestSchema spawnEventRequestSchema, {Future<void>? abortTrigger}) Future<Response>
Spawn Event
teleportSandboxTeleportPost(SandboxTeleportSchema sandboxTeleportSchema, {Future<void>? abortTrigger}) Future<SandboxTeleportResponseSchema?>
Teleport
teleportSandboxTeleportPostWithHttpInfo(SandboxTeleportSchema sandboxTeleportSchema, {Future<void>? abortTrigger}) Future<Response>
Teleport
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited