giveXpSandboxGiveXpPost method

Future<SandboxGiveXPResponseSchema?> giveXpSandboxGiveXpPost(
  1. SandboxGiveXPSchema sandboxGiveXPSchema, {
  2. Future<void>? abortTrigger,
})

Give Xp

Give XP to one of your characters. This Sandbox feature is only available on the Sandbox server.

Parameters:

Implementation

Future<SandboxGiveXPResponseSchema?> giveXpSandboxGiveXpPost(
  SandboxGiveXPSchema sandboxGiveXPSchema, {
  Future<void>? abortTrigger,
}) async {
  final response = await giveXpSandboxGiveXpPostWithHttpInfo(
    sandboxGiveXPSchema,
    abortTrigger: abortTrigger,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty &&
      response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'SandboxGiveXPResponseSchema',
    ) as SandboxGiveXPResponseSchema;
  }
  return null;
}