resetAccountSandboxResetAccountPost method
Reset Account
Reset your account to its initial state. This will delete all characters, bank items, pending items, logs, achievements, and progress. This Sandbox feature is only available on the Sandbox server.
Implementation
Future<ResponseSchema?> resetAccountSandboxResetAccountPost({
Future<void>? abortTrigger,
}) async {
final response = await resetAccountSandboxResetAccountPostWithHttpInfo(
abortTrigger: abortTrigger,
);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty &&
response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(
await _decodeBodyBytes(response),
'ResponseSchema',
) as ResponseSchema;
}
return null;
}