resetAccountSandboxResetAccountPostWithHttpInfo method
Reset Account
Reset your account to its initial state. This will delete all characters, bank items, pending items, logs, achievements, and progress. This Sandbox feature is only available on the Sandbox server.
Note: This method returns the HTTP Response.
Implementation
Future<Response> resetAccountSandboxResetAccountPostWithHttpInfo({
Future<void>? abortTrigger,
}) async {
// ignore: prefer_const_declarations
final path = r'/sandbox/reset_account';
// ignore: prefer_final_locals
Object? postBody;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
const contentTypes = <String>[];
return apiClient.invokeAPI(
path,
'POST',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes.first,
abortTrigger: abortTrigger,
);
}