teleportSandboxTeleportPost method
Future<SandboxTeleportResponseSchema?>
teleportSandboxTeleportPost(
- SandboxTeleportSchema sandboxTeleportSchema, {
- Future<
void> ? abortTrigger,
Teleport
Teleport a character directly to a map by ID without path or access checks. This Sandbox feature is only available on the Sandbox server.
Parameters:
- SandboxTeleportSchema sandboxTeleportSchema (required):
Implementation
Future<SandboxTeleportResponseSchema?> teleportSandboxTeleportPost(
SandboxTeleportSchema sandboxTeleportSchema, {
Future<void>? abortTrigger,
}) async {
final response = await teleportSandboxTeleportPostWithHttpInfo(
sandboxTeleportSchema,
abortTrigger: abortTrigger,
);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty &&
response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(
await _decodeBodyBytes(response),
'SandboxTeleportResponseSchema',
) as SandboxTeleportResponseSchema;
}
return null;
}