teleportSandboxTeleportPostWithHttpInfo method

Future<Response> teleportSandboxTeleportPostWithHttpInfo(
  1. SandboxTeleportSchema sandboxTeleportSchema, {
  2. Future<void>? abortTrigger,
})

Teleport

Teleport a character directly to a map by ID without path or access checks. This Sandbox feature is only available on the Sandbox server.

Note: This method returns the HTTP Response.

Parameters:

Implementation

Future<Response> teleportSandboxTeleportPostWithHttpInfo(
  SandboxTeleportSchema sandboxTeleportSchema, {
  Future<void>? abortTrigger,
}) async {
  // ignore: prefer_const_declarations
  final path = r'/sandbox/teleport';

  // ignore: prefer_final_locals
  Object? postBody = sandboxTeleportSchema;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

  const contentTypes = <String>['application/json'];

  return apiClient.invokeAPI(
    path,
    'POST',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes.first,
    abortTrigger: abortTrigger,
  );
}