SandboxGiveXPDataSchema class

Constructors

SandboxGiveXPDataSchema({required CooldownSchema cooldown, required XPType type, required int amount, required CharacterSchema character})
Returns a new SandboxGiveXPDataSchema instance.

Properties

amount int
Amount of XP given.
getter/setter pair
character CharacterSchema
Character details of the receiving character.
getter/setter pair
cooldown CooldownSchema
Cooldown details.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type XPType
Type of XP given.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SandboxGiveXPDataSchema?
Returns a new SandboxGiveXPDataSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SandboxGiveXPDataSchema>
mapFromJson(dynamic json) Map<String, SandboxGiveXPDataSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SandboxGiveXPDataSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.