SandboxGiveXPSchema class

Constructors

SandboxGiveXPSchema({required XPType type, required int amount, required String character})
Returns a new SandboxGiveXPSchema instance.

Properties

amount int
Amount of XP to give to the character.
getter/setter pair
character String
Name of the character to receive the XP.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type XPType
Type of XP to give (e.g., 'combat', 'woodcutting', 'mining', etc.).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SandboxGiveXPSchema?
Returns a new SandboxGiveXPSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SandboxGiveXPSchema>
mapFromJson(dynamic json) Map<String, SandboxGiveXPSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SandboxGiveXPSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.