SandboxTeleportResponseSchema class

Constructors

SandboxTeleportResponseSchema({required SandboxTeleportDataSchema data})
Returns a new SandboxTeleportResponseSchema instance.

Properties

data SandboxTeleportDataSchema
Sandbox teleport data.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SandboxTeleportResponseSchema?
Returns a new SandboxTeleportResponseSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SandboxTeleportResponseSchema>
mapFromJson(dynamic json) Map<String, SandboxTeleportResponseSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SandboxTeleportResponseSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.