SandboxTeleportSchema class

Constructors

SandboxTeleportSchema({required String character, required int mapId})
Returns a new SandboxTeleportSchema instance.

Properties

character String
Character name.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
mapId int
ID of the destination map.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SandboxTeleportSchema?
Returns a new SandboxTeleportSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SandboxTeleportSchema>
mapFromJson(dynamic json) Map<String, SandboxTeleportSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SandboxTeleportSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.