SeasonRewardsApi class

Constructors

SeasonRewardsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllSeasonRewardsSeasonRewardsGet({RewardType? type, int? page, int? size, Future<void>? abortTrigger}) Future<StaticDataPageSeasonRewardSchema?>
Get All Season Rewards
getAllSeasonRewardsSeasonRewardsGetWithHttpInfo({RewardType? type, int? page, int? size, Future<void>? abortTrigger}) Future<Response>
Get All Season Rewards
getSeasonRewardsByCodeSeasonRewardsCodeGet(String code, {int? page, int? size, Future<void>? abortTrigger}) Future<StaticDataPageSeasonRewardSchema?>
Get Season Rewards By Code
getSeasonRewardsByCodeSeasonRewardsCodeGetWithHttpInfo(String code, {int? page, int? size, Future<void>? abortTrigger}) Future<Response>
Get Season Rewards By Code
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited