rewards property
Season rewards with required achievement points, sorted by points ascending.
Implementation
List<StatusSeasonRewardSchema> rewards;
Season rewards with required achievement points, sorted by points ascending.
List<StatusSeasonRewardSchema> rewards;