SeasonSkinSchema class

Constructors

SeasonSkinSchema({required String code, required String description, required int requiredPoints})
Returns a new SeasonSkinSchema instance.

Properties

code String
Skin code.
getter/setter pair
description String
Skin description.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
requiredPoints int
Required achievement points to earn the skin.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SeasonSkinSchema?
Returns a new SeasonSkinSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SeasonSkinSchema>
mapFromJson(dynamic json) Map<String, SeasonSkinSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SeasonSkinSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.