SimpleEffectSchema class

Constructors

SimpleEffectSchema({required String code, required int value, required String description})
Returns a new SimpleEffectSchema instance.

Properties

code String
Effect code.
getter/setter pair
description String
Description of the effect.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
Effect value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SimpleEffectSchema?
Returns a new SimpleEffectSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SimpleEffectSchema>
mapFromJson(dynamic json) Map<String, SimpleEffectSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SimpleEffectSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.