SimulationApi class

Constructors

SimulationApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fightSimulationSimulationFightSimulationPost(CombatSimulationRequestSchema combatSimulationRequestSchema) Future<CombatSimulationResponseSchema?>
Fight Simulation
fightSimulationSimulationFightSimulationPostWithHttpInfo(CombatSimulationRequestSchema combatSimulationRequestSchema) Future<Response>
Fight Simulation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited