SkillInfoSchema class

Constructors

SkillInfoSchema({required int xp, List<DropSchema> items = const []})
Returns a new SkillInfoSchema instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
items List<DropSchema>
Objects received.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xp int
The amount of xp gained.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SkillInfoSchema?
Returns a new SkillInfoSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SkillInfoSchema>
mapFromJson(dynamic json) Map<String, SkillInfoSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SkillInfoSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.