SkinSchema class

Constructors

SkinSchema({required String code, required String name, required String description, required bool default_, int? price})
Returns a new SkinSchema instance.

Properties

code String
The code of the skin. This is the skin's unique identifier.
getter/setter pair
default_ bool
Whether this skin is available to all players by default.
getter/setter pair
description String
Description of the skin and how to obtain it.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
name String
Display name of the skin.
getter/setter pair
price int?
Price in gems to purchase this skin. Null if not purchasable.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SkinSchema?
Returns a new SkinSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SkinSchema>
mapFromJson(dynamic json) Map<String, SkinSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SkinSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.