SkinsApi class

Constructors

SkinsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllSkinsSkinsGet({int? page, int? size, Future<void>? abortTrigger}) Future<StaticDataPageSkinSchema?>
Get All Skins
getAllSkinsSkinsGetWithHttpInfo({int? page, int? size, Future<void>? abortTrigger}) Future<Response>
Get All Skins
getSkinSkinsCodeGet(String code, {Future<void>? abortTrigger}) Future<SkinResponseSchema?>
Get Skin
getSkinSkinsCodeGetWithHttpInfo(String code, {Future<void>? abortTrigger}) Future<Response>
Get Skin
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited