SpawnEventRequest class

Constructors

SpawnEventRequest({required String code})
Returns a new SpawnEventRequest instance.

Properties

code String
Code of the event to spawn
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SpawnEventRequest?
Returns a new SpawnEventRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SpawnEventRequest>
mapFromJson(dynamic json) Map<String, SpawnEventRequest>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SpawnEventRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.