StaticDataPageMapSchema class

Constructors

StaticDataPageMapSchema({List<MapSchema> data = const [], int? total, int? page, int? size, int? pages})
Returns a new StaticDataPageMapSchema instance.

Properties

data List<MapSchema>
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
page int?
Minimum value: 1
getter/setter pair
pages int?
Minimum value: 0
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
Minimum value: 1
getter/setter pair
total int?
Minimum value: 0
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) StaticDataPageMapSchema?
Returns a new StaticDataPageMapSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<StaticDataPageMapSchema>
mapFromJson(dynamic json) Map<String, StaticDataPageMapSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<StaticDataPageMapSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.