SubscriptionSchema class
Constructors
- SubscriptionSchema({required SubscriptionPlan plan, required SubscriptionSchemaPurchaseSourceEnum purchaseSource, required String status, required DateTime currentPeriodStart, required DateTime currentPeriodEnd, required DateTime createdAt, DateTime? cancelledAt})
- Returns a new SubscriptionSchema instance.
Properties
- cancelledAt ↔ DateTime?
-
When the subscription was cancelled.
getter/setter pair
- createdAt ↔ DateTime
-
When the subscription was created.
getter/setter pair
- currentPeriodEnd ↔ DateTime
-
End of the current billing period.
getter/setter pair
- currentPeriodStart ↔ DateTime
-
Start of the current billing period.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- plan ↔ SubscriptionPlan
-
Subscription plan (monthly, annual, or prepaid).
getter/setter pair
- purchaseSource ↔ SubscriptionSchemaPurchaseSourceEnum
-
How the subscription was purchased. Mixed means both gems and member tokens were used.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String
-
Subscription status (active, cancelled, past_due, expired).
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → SubscriptionSchema? -
Returns a new SubscriptionSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< SubscriptionSchema> -
mapFromJson(
dynamic json) → Map< String, SubscriptionSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< SubscriptionSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.