purchaseSource property
How the subscription was purchased. Mixed means both gems and member tokens were used.
Implementation
SubscriptionSchemaPurchaseSourceEnum purchaseSource;
How the subscription was purchased. Mixed means both gems and member tokens were used.
SubscriptionSchemaPurchaseSourceEnum purchaseSource;