TaskFullSchema class
Constructors
- TaskFullSchema({required String code, required int level, required TaskType type, required int minQuantity, required int maxQuantity, String? skill, required RewardsSchema rewards})
- Returns a new TaskFullSchema instance.
Properties
- code ↔ String
-
Task objective.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- level ↔ int
-
Task level.
getter/setter pair
- maxQuantity ↔ int
-
Maximum amount of task.
getter/setter pair
- minQuantity ↔ int
-
Minimum amount of task.
getter/setter pair
- rewards ↔ RewardsSchema
-
Rewards.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skill ↔ String?
-
Skill required to complete the task.
getter/setter pair
- type ↔ TaskType
-
The type of task.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → TaskFullSchema? -
Returns a new TaskFullSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< TaskFullSchema> -
mapFromJson(
dynamic json) → Map< String, TaskFullSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< TaskFullSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.