TaskSchema class
Constructors
- TaskSchema({required String code, required TaskType type, required int total, required RewardsSchema rewards})
- Returns a new TaskSchema instance.
Properties
- code ↔ String
-
Task objective.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- rewards ↔ RewardsSchema
-
Rewards for completing the task.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total ↔ int
-
The total required to complete the task.
getter/setter pair
- type ↔ TaskType
-
The type of task.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → TaskSchema? -
Returns a new TaskSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< TaskSchema> -
mapFromJson(
dynamic json) → Map< String, TaskSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< TaskSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.