TasksApi class

Constructors

TasksApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllTasksRewardsTasksRewardsGet({int? page, int? size}) Future<StaticDataPageDropRateSchema?>
Get All Tasks Rewards
getAllTasksRewardsTasksRewardsGetWithHttpInfo({int? page, int? size}) Future<Response>
Get All Tasks Rewards
getAllTasksTasksListGet({int? minLevel, int? maxLevel, Skill? skill, TaskType? type, int? page, int? size}) Future<StaticDataPageTaskFullSchema?>
Get All Tasks
getAllTasksTasksListGetWithHttpInfo({int? minLevel, int? maxLevel, Skill? skill, TaskType? type, int? page, int? size}) Future<Response>
Get All Tasks
getTasksRewardTasksRewardsCodeGet(String code) Future<RewardResponseSchema?>
Get Tasks Reward
getTasksRewardTasksRewardsCodeGetWithHttpInfo(String code) Future<Response>
Get Tasks Reward
getTaskTasksListCodeGet(String code) Future<TaskFullResponseSchema?>
Get Task
getTaskTasksListCodeGetWithHttpInfo(String code) Future<Response>
Get Task
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited