generateTokenTokenPost method

Future<TokenResponseSchema?> generateTokenTokenPost()

Generate Token

Use your account as HTTPBasic Auth to generate your token to use the API. You can also generate your token directly on the website.

Implementation

Future<TokenResponseSchema?> generateTokenTokenPost() async {
  final response = await generateTokenTokenPostWithHttpInfo();
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty &&
      response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'TokenResponseSchema',
    ) as TokenResponseSchema;
  }
  return null;
}