generateTokenTokenPostWithHttpInfo method

Future<Response> generateTokenTokenPostWithHttpInfo()

Generate Token

Use your account as HTTPBasic Auth to generate your token to use the API. You can also generate your token directly on the website.

Note: This method returns the HTTP Response.

Implementation

Future<Response> generateTokenTokenPostWithHttpInfo() async {
  // ignore: prefer_const_declarations
  final path = r'/token';

  // ignore: prefer_final_locals
  Object? postBody;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

  const contentTypes = <String>[];

  return apiClient.invokeAPI(
    path,
    'POST',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes.first,
  );
}