UnequipSchema class

Constructors

UnequipSchema({required ItemSlot slot, int quantity = 1})
Returns a new UnequipSchema instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
quantity int
Item quantity. Applicable to utilities only.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slot ItemSlot
Item slot.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) UnequipSchema?
Returns a new UnequipSchema instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<UnequipSchema>
mapFromJson(dynamic json) Map<String, UnequipSchema>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<UnequipSchema>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.