XPType class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) XPType?
listFromJson(dynamic json, {bool growable = false}) List<XPType>

Constants

alchemy → const XPType
combat → const XPType
cooking → const XPType
fishing → const XPType
gearcrafting → const XPType
jewelrycrafting → const XPType
mining → const XPType
values → const List<XPType>
List of all possible values in this XPType.
weaponcrafting → const XPType
woodcutting → const XPType