api
library
Classes
-
AccessSchema
-
-
AccountAchievementObjectiveSchema
-
-
AccountAchievementSchema
-
-
AccountDetails
-
-
AccountDetailsSchema
-
-
AccountLeaderboardSchema
-
-
AccountLeaderboardType
-
-
AccountLeaderboardTypeTypeTransformer
-
Transformation class that can encode an instance of AccountLeaderboardType to String,
and decode dynamic data back to AccountLeaderboardType.
-
AccountsApi
-
-
AccountStatus
-
-
AccountStatusTypeTransformer
-
Transformation class that can encode an instance of AccountStatus to String,
and decode dynamic data back to AccountStatus.
-
AchievementObjectiveSchema
-
-
AchievementResponseSchema
-
-
AchievementRewardsSchema
-
-
AchievementsApi
-
-
AchievementSchema
-
-
AchievementType
-
-
AchievementTypeTypeTransformer
-
Transformation class that can encode an instance of AchievementType to String,
and decode dynamic data back to AchievementType.
-
ActionType
-
-
ActionTypeTypeTransformer
-
Transformation class that can encode an instance of ActionType to String,
and decode dynamic data back to ActionType.
-
ActiveCharacterSchema
-
-
ActiveEventResponseSchema
-
-
ActiveEventSchema
-
-
AddAccountSchema
-
-
AddCharacterSchema
-
-
ApiClient
-
-
ApiKeyAuth
-
-
Authentication
-
-
BadgeConditionSchema
-
-
BadgeResponseSchema
-
-
BadgesApi
-
-
BadgeSchema
-
-
BankExtensionSchema
-
-
BankExtensionTransactionResponseSchema
-
-
BankExtensionTransactionSchema
-
-
BankGoldTransactionResponseSchema
-
-
BankGoldTransactionSchema
-
-
BankItemTransactionResponseSchema
-
-
BankItemTransactionSchema
-
-
BankResponseSchema
-
-
BankSchema
-
-
ChangePassword
-
-
ChangeSkinCharacterDataSchema
-
-
ChangeSkinCharacterSchema
-
-
ChangeSkinResponseSchema
-
-
CharacterFightDataSchema
-
-
CharacterFightResponseSchema
-
-
CharacterFightSchema
-
-
CharacterLeaderboardSchema
-
-
CharacterLeaderboardType
-
-
CharacterLeaderboardTypeTypeTransformer
-
Transformation class that can encode an instance of CharacterLeaderboardType to String,
and decode dynamic data back to CharacterLeaderboardType.
-
CharacterMovementDataSchema
-
-
CharacterMovementResponseSchema
-
-
CharacterMultiFightResultSchema
-
-
CharacterResponseSchema
-
-
CharacterRestDataSchema
-
-
CharacterRestResponseSchema
-
-
CharactersApi
-
-
CharacterSchema
-
-
CharacterSkin
-
-
CharacterSkinTypeTransformer
-
Transformation class that can encode an instance of CharacterSkin to String,
and decode dynamic data back to CharacterSkin.
-
CharactersListSchema
-
-
CharacterTransitionDataSchema
-
-
CharacterTransitionResponseSchema
-
-
ClaimPendingItemDataSchema
-
-
ClaimPendingItemResponseSchema
-
-
CombatResultSchema
-
-
CombatSimulationDataSchema
-
-
CombatSimulationRequestSchema
-
-
CombatSimulationResponseSchema
-
-
ConditionOperator
-
-
ConditionOperatorTypeTransformer
-
Transformation class that can encode an instance of ConditionOperator to String,
and decode dynamic data back to ConditionOperator.
-
ConditionSchema
-
-
CooldownSchema
-
-
CraftingSchema
-
-
CraftSchema
-
-
CraftSkill
-
-
CraftSkillTypeTransformer
-
Transformation class that can encode an instance of CraftSkill to String,
and decode dynamic data back to CraftSkill.
-
DataPageAccountAchievementSchema
-
-
DataPageAccountLeaderboardSchema
-
-
DataPageActiveCharacterSchema
-
-
DataPageCharacterLeaderboardSchema
-
-
DataPageGeOrderHistorySchema
-
-
DataPageGEOrderSchema
-
-
DataPageLogSchema
-
-
DataPagePendingItemSchema
-
-
DataPageSimpleItemSchema
-
-
DeleteCharacterSchema
-
-
DeleteItemResponseSchema
-
-
DeleteItemSchema
-
-
DepositWithdrawGoldSchema
-
-
DeserializationMessage
-
Primarily intended for use in an isolate.
-
DestinationSchema
-
-
DropRateSchema
-
-
DropSchema
-
-
EffectResponseSchema
-
-
EffectsApi
-
-
EffectSchema
-
-
EffectSubtype
-
-
EffectSubtypeTypeTransformer
-
Transformation class that can encode an instance of EffectSubtype to String,
and decode dynamic data back to EffectSubtype.
-
EffectType
-
-
EffectTypeTypeTransformer
-
Transformation class that can encode an instance of EffectType to String,
and decode dynamic data back to EffectType.
-
EquipmentResponseSchema
-
-
EquipRequestSchema
-
-
EquipSchema
-
-
ErrorResponseSchema
-
-
ErrorSchema
-
-
EventContentSchema
-
-
EventMapSchema
-
-
EventsApi
-
-
EventSchema
-
-
FakeCharacterSchema
-
-
FightRequestSchema
-
-
FightResult
-
-
FightResultTypeTransformer
-
Transformation class that can encode an instance of FightResult to String,
and decode dynamic data back to FightResult.
-
GatheringSkill
-
-
GatheringSkillTypeTransformer
-
Transformation class that can encode an instance of GatheringSkill to String,
and decode dynamic data back to GatheringSkill.
-
GEBuyOrderCreationSchema
-
-
GEBuyOrderSchema
-
-
GECancelOrderSchema
-
-
GECreateOrderTransactionResponseSchema
-
-
GEFillBuyOrderSchema
-
-
GEOrderCreatedSchema
-
-
GEOrderCreationrSchema
-
-
GeOrderHistorySchema
-
-
GEOrderResponseSchema
-
-
GEOrderSchema
-
-
GEOrderTransactionSchema
-
-
GEOrderType
-
Type of Grand Exchange order.
-
GEOrderTypeTypeTransformer
-
Transformation class that can encode an instance of GEOrderType to String,
and decode dynamic data back to GEOrderType.
-
GETransactionListSchema
-
-
GETransactionResponseSchema
-
-
GETransactionSchema
-
-
GiveGoldDataSchema
-
-
GiveGoldResponseSchema
-
-
GiveGoldSchema
-
-
GiveItemDataSchema
-
-
GiveItemResponseSchema
-
-
GiveItemsSchema
-
-
GoldSchema
-
-
GrandExchangeApi
-
-
HttpBasicAuth
-
-
HttpBearerAuth
-
-
HTTPValidationError
-
-
InteractionSchema
-
-
InventorySlot
-
-
ItemResponseSchema
-
-
ItemsApi
-
-
ItemSchema
-
-
ItemSlot
-
-
ItemSlotTypeTransformer
-
Transformation class that can encode an instance of ItemSlot to String,
and decode dynamic data back to ItemSlot.
-
ItemType
-
-
ItemTypeTypeTransformer
-
Transformation class that can encode an instance of ItemType to String,
and decode dynamic data back to ItemType.
-
LeaderboardApi
-
-
LogSchema
-
-
LogType
-
-
LogTypeTypeTransformer
-
Transformation class that can encode an instance of LogType to String,
and decode dynamic data back to LogType.
-
MapAccessType
-
-
MapAccessTypeTypeTransformer
-
Transformation class that can encode an instance of MapAccessType to String,
and decode dynamic data back to MapAccessType.
-
MapContentSchema
-
-
MapContentType
-
-
MapContentTypeTypeTransformer
-
Transformation class that can encode an instance of MapContentType to String,
and decode dynamic data back to MapContentType.
-
MapLayer
-
-
MapLayerTypeTransformer
-
Transformation class that can encode an instance of MapLayer to String,
and decode dynamic data back to MapLayer.
-
MapResponseSchema
-
-
MapsApi
-
-
MapSchema
-
-
MonsterResponseSchema
-
-
MonstersApi
-
-
MonsterSchema
-
-
MonsterType
-
-
MonsterTypeTypeTransformer
-
Transformation class that can encode an instance of MonsterType to String,
and decode dynamic data back to MonsterType.
-
MyAccountApi
-
-
MyAccountDetails
-
-
MyAccountDetailsSchema
-
-
MyCharactersApi
-
-
MyCharactersListSchema
-
-
NPCItem
-
-
NpcItemTransactionSchema
-
-
NpcMerchantBuySchema
-
-
NpcMerchantTransactionResponseSchema
-
-
NpcMerchantTransactionSchema
-
-
NPCResponseSchema
-
-
NPCsApi
-
-
NPCSchema
-
-
NPCType
-
-
NPCTypeTypeTransformer
-
Transformation class that can encode an instance of NPCType to String,
and decode dynamic data back to NPCType.
-
OAuth
-
-
PasswordResetConfirmSchema
-
-
PasswordResetRequestSchema
-
-
PasswordResetResponseSchema
-
-
PendingItemSchema
-
-
PendingItemSource
-
Source types for pending items.
-
PendingItemSourceTypeTransformer
-
Transformation class that can encode an instance of PendingItemSource to String,
and decode dynamic data back to PendingItemSource.
-
QueryParam
-
-
RateLimitSchema
-
-
RecyclingDataSchema
-
-
RecyclingItemsSchema
-
-
RecyclingResponseSchema
-
-
RecyclingSchema
-
-
ResourceResponseSchema
-
-
ResourcesApi
-
-
ResourceSchema
-
-
ResponseSchema
-
-
RewardDataResponseSchema
-
-
RewardDataSchema
-
-
RewardItemSchema
-
-
RewardResponseSchema
-
-
RewardsSchema
-
-
SeasonBadgeSchema
-
-
SeasonSchema
-
-
SeasonSkinSchema
-
-
ServerDetailsApi
-
-
SimpleEffectSchema
-
-
SimpleItemSchema
-
-
SimulationApi
-
-
Skill
-
-
SkillDataSchema
-
-
SkillInfoSchema
-
-
SkillResponseSchema
-
-
SkillTypeTransformer
-
Transformation class that can encode an instance of Skill to String,
and decode dynamic data back to Skill.
-
SpawnEventRequest
-
-
StaticDataPageAchievementSchema
-
-
StaticDataPageActiveEventSchema
-
-
StaticDataPageBadgeSchema
-
-
StaticDataPageDropRateSchema
-
-
StaticDataPageEffectSchema
-
-
StaticDataPageEventSchema
-
-
StaticDataPageItemSchema
-
-
StaticDataPageMapSchema
-
-
StaticDataPageMonsterSchema
-
-
StaticDataPageNPCItem
-
-
StaticDataPageNPCSchema
-
-
-
StaticDataPageTaskFullSchema
-
-
StatusResponseSchema
-
-
StatusSchema
-
-
StorageEffectSchema
-
-
TaskCancelledResponseSchema
-
-
TaskCancelledSchema
-
-
TaskDataSchema
-
-
TaskFullResponseSchema
-
-
TaskFullSchema
-
-
TaskResponseSchema
-
-
TasksApi
-
-
TaskSchema
-
-
TaskTradeDataSchema
-
-
TaskTradeResponseSchema
-
-
TaskTradeSchema
-
-
TaskType
-
-
TaskTypeTypeTransformer
-
Transformation class that can encode an instance of TaskType to String,
and decode dynamic data back to TaskType.
-
TokenApi
-
-
TokenResponseSchema
-
-
TransitionSchema
-
-
UnequipSchema
-
-
UseItemResponseSchema
-
-
UseItemSchema
-
-
ValidationError
-
-
ValidationErrorLocInner
-
Functions
-
decodeAsync(DeserializationMessage message)
→ Future
-
Primarily intended for use in an isolate.
-
deserializeAsync(DeserializationMessage message)
→ Future
-
Primarily intended for use in an isolate.
-
mapCastOfType<K, V>(dynamic map, String key)
→ Map<K, V>?
-
Returns a valid Map<K, V> found at the specified Map
key, null otherwise.
-
mapDateTime(dynamic map, String key, [String? pattern])
→ DateTime?
-
Returns a valid DateTime found at the specified Map
key, null otherwise.
-
mapValueOfType<T>(dynamic map, String key)
→ T?
-
Returns a valid
T value found at the specified Map key, null otherwise.
-
parameterToString(dynamic value)
→ String
-
Format the given parameter object into a String.
-
serializeAsync(Object? value)
→ Future<String>
-
Primarily intended for use in an isolate.