api library

Classes

AccountAchievementSchema
AccountDetails
AccountDetailsSchema
AccountLeaderboardSchema
AccountLeaderboardType
AccountLeaderboardTypeTypeTransformer
Transformation class that can encode an instance of AccountLeaderboardType to String, and decode dynamic data back to AccountLeaderboardType.
AccountsApi
AccountStatus
AccountStatusTypeTransformer
Transformation class that can encode an instance of AccountStatus to String, and decode dynamic data back to AccountStatus.
AchievementResponseSchema
AchievementRewardsSchema
AchievementsApi
AchievementSchema
AchievementType
AchievementTypeTypeTransformer
Transformation class that can encode an instance of AchievementType to String, and decode dynamic data back to AchievementType.
ActionType
ActionTypeTypeTransformer
Transformation class that can encode an instance of ActionType to String, and decode dynamic data back to ActionType.
ActiveEventSchema
AddAccountSchema
AddCharacterSchema
AnnouncementSchema
ApiClient
ApiKeyAuth
Authentication
BankExtensionSchema
BankExtensionTransactionResponseSchema
BankExtensionTransactionSchema
BankGoldTransactionResponseSchema
BankGoldTransactionSchema
BankItemTransactionResponseSchema
BankItemTransactionSchema
BankResponseSchema
BankSchema
BaseAchievementSchema
BaseAchievementSchemaTypeEnum
Type of achievement.
BaseAchievementSchemaTypeEnumTypeTransformer
Transformation class that can encode an instance of BaseAchievementSchemaTypeEnum to String, and decode dynamic data back to BaseAchievementSchemaTypeEnum.
BlockedHitsSchema
ChangePassword
CharacterFightDataSchema
CharacterFightResponseSchema
CharacterLeaderboardSchema
CharacterLeaderboardType
CharacterLeaderboardTypeTypeTransformer
Transformation class that can encode an instance of CharacterLeaderboardType to String, and decode dynamic data back to CharacterLeaderboardType.
CharacterMovementDataSchema
CharacterMovementResponseSchema
CharacterResponseSchema
CharacterRestDataSchema
CharacterRestResponseSchema
CharactersApi
CharacterSchema
CharacterSkin
CharacterSkinTypeTransformer
Transformation class that can encode an instance of CharacterSkin to String, and decode dynamic data back to CharacterSkin.
CooldownSchema
CraftingSchema
CraftSchema
CraftSkill
CraftSkillTypeTransformer
Transformation class that can encode an instance of CraftSkill to String, and decode dynamic data back to CraftSkill.
DataPageAccountAchievementSchema
DataPageAccountLeaderboardSchema
DataPageAchievementSchema
DataPageActiveEventSchema
DataPageCharacterLeaderboardSchema
DataPageDropRateSchema
DataPageEventSchema
DataPageGeOrderHistorySchema
DataPageGEOrderSchema
DataPageItemSchema
DataPageLogSchema
DataPageMapSchema
DataPageMonsterSchema
DataPageResourceSchema
DataPageSimpleItemSchema
DataPageTaskFullSchema
DefaultApi
DeleteCharacterSchema
DeleteItemResponseSchema
DeleteItemSchema
DepositWithdrawGoldSchema
DeserializationMessage
Primarily intended for use in an isolate.
DestinationSchema
DropRateSchema
DropSchema
EquipmentResponseSchema
EquipRequestSchema
EquipSchema
EventContentSchema
EventMapSchema
EventsApi
EventSchema
FightResult
FightResultTypeTransformer
Transformation class that can encode an instance of FightResult to String, and decode dynamic data back to FightResult.
FightSchema
GatheringSkill
GatheringSkillTypeTransformer
Transformation class that can encode an instance of GatheringSkill to String, and decode dynamic data back to GatheringSkill.
GEBuyOrderSchema
GECancelOrderSchema
GECreateOrderTransactionResponseSchema
GEOrderCreatedSchema
GEOrderCreationrSchema
GeOrderHistorySchema
GEOrderReponseSchema
GEOrderSchema
GEOrderTransactionSchema
GETransactionListSchema
GETransactionResponseSchema
GETransactionSchema
GoldSchema
GrandExchangeApi
HttpBasicAuth
HttpBearerAuth
HTTPValidationError
InventorySlot
ItemEffectSchema
ItemResponseSchema
ItemsApi
ItemSchema
ItemSlot
ItemSlotTypeTransformer
Transformation class that can encode an instance of ItemSlot to String, and decode dynamic data back to ItemSlot.
LeaderboardApi
LogSchema
LogType
LogTypeTypeTransformer
Transformation class that can encode an instance of LogType to String, and decode dynamic data back to LogType.
MapContentSchema
MapContentType
MapContentTypeTypeTransformer
Transformation class that can encode an instance of MapContentType to String, and decode dynamic data back to MapContentType.
MapResponseSchema
MapsApi
MapSchema
MonsterResponseSchema
MonstersApi
MonsterSchema
MyAccountApi
MyAccountDetails
MyAccountDetailsSchema
MyCharactersApi
MyCharactersListSchema
OAuth
QueryParam
RecyclingDataSchema
RecyclingItemsSchema
RecyclingResponseSchema
RecyclingSchema
ResourceResponseSchema
ResourcesApi
ResourceSchema
ResponseSchema
SimpleItemSchema
Skill
SkillDataSchema
SkillInfoSchema
SkillResponseSchema
SkillTypeTransformer
Transformation class that can encode an instance of Skill to String, and decode dynamic data back to Skill.
StatusResponseSchema
StatusSchema
TaskCancelledResponseSchema
TaskCancelledSchema
TaskDataSchema
TaskFullResponseSchema
TaskFullSchema
TaskResponseSchema
TaskRewardsSchema
TasksApi
TaskSchema
TasksRewardDataResponseSchema
TasksRewardDataSchema
TasksRewardResponseSchema
TaskTradeDataSchema
TaskTradeResponseSchema
TaskTradeSchema
TaskType
TaskTypeTypeTransformer
Transformation class that can encode an instance of TaskType to String, and decode dynamic data back to TaskType.
TokenApi
TokenResponseSchema
UnequipSchema
UseItemResponseSchema
UseItemSchema
ValidationError
ValidationErrorLocInner

Properties

defaultApiClient ApiClient
An ApiClient instance that uses the default values obtained from the OpenAPI specification file.
getter/setter pair

Functions

decodeAsync(DeserializationMessage message) Future
Primarily intended for use in an isolate.
deserializeAsync(DeserializationMessage message) Future
Primarily intended for use in an isolate.
mapCastOfType<K, V>(dynamic map, String key) Map<K, V>?
Returns a valid Map<K, V> found at the specified Map key, null otherwise.
mapDateTime(dynamic map, String key, [String? pattern]) DateTime?
Returns a valid DateTime found at the specified Map key, null otherwise.
mapValueOfType<T>(dynamic map, String key) → T?
Returns a valid T value found at the specified Map key, null otherwise.
parameterToString(dynamic value) String
Format the given parameter object into a String.
serializeAsync(Object? value) Future<String>
Primarily intended for use in an isolate.

Typedefs

HttpBearerAuthProvider = String Function()

Exceptions / Errors

ApiException