status property
Account status. Status for contributors during the alpha and beta phases. It is no longer possible to obtain founder status.
Implementation
AccountStatus status;
Account status. Status for contributors during the alpha and beta phases. It is no longer possible to obtain founder status.
AccountStatus status;