AccountLeaderboardSchema class
Constructors
- AccountLeaderboardSchema({required int position, required String account, required AccountStatus status, required int achievementsPoints, required int gold})
- Returns a new AccountLeaderboardSchema instance.
Properties
- account ↔ String
-
Account name.
getter/setter pair
- achievementsPoints ↔ int
-
Achievements points.
getter/setter pair
- gold ↔ int
-
Gold in the account.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- position ↔ int
-
Position in the leaderboard.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ AccountStatus
-
Member status.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → AccountLeaderboardSchema? -
Returns a new AccountLeaderboardSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< AccountLeaderboardSchema> -
mapFromJson(
dynamic json) → Map< String, AccountLeaderboardSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< AccountLeaderboardSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.