CombatResultSchema class
Constructors
-
CombatResultSchema({required String result, required int turns, List<
String> logs = const [], List<Object> characterResults = const []}) - Returns a new CombatResultSchema instance.
Properties
-
characterResults
↔ List<
Object> -
Character results from combat.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
-
logs
↔ List<
String> -
Combat logs.
getter/setter pair
- result ↔ String
-
Combat result: 'win' or 'loss'.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- turns ↔ int
-
Number of turns the combat lasted.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → CombatResultSchema? -
Returns a new CombatResultSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< CombatResultSchema> -
listObjectFromJson(
dynamic json) → List< Object> ? -
mapFromJson(
dynamic json) → Map< String, CombatResultSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< CombatResultSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.