EffectSchema class
Constructors
- EffectSchema({required String name, required String code, required String description, required EffectType type, required EffectSubtype subtype})
- Returns a new EffectSchema instance.
Properties
- code ↔ String
-
The code of the effect. This is the effect's unique identifier (ID).
getter/setter pair
- description ↔ String
-
Description of the effect. This is a brief description of the effect.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- name ↔ String
-
Name of the effect.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtype ↔ EffectSubtype
-
Subtype of the effect.
getter/setter pair
- type ↔ EffectType
-
Type of the effect.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → EffectSchema? -
Returns a new EffectSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< EffectSchema> -
mapFromJson(
dynamic json) → Map< String, EffectSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< EffectSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.