EquipRequestSchema class
Constructors
- EquipRequestSchema({required CooldownSchema cooldown, required ItemSlot slot, required ItemSchema item, required CharacterSchema character})
- Returns a new EquipRequestSchema instance.
Properties
- character ↔ CharacterSchema
-
Player details.
getter/setter pair
- cooldown ↔ CooldownSchema
-
Cooldown details.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- item ↔ ItemSchema
-
Item details.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slot ↔ ItemSlot
-
Item slot.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → EquipRequestSchema? -
Returns a new EquipRequestSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< EquipRequestSchema> -
mapFromJson(
dynamic json) → Map< String, EquipRequestSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< EquipRequestSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.