FakeCharacterSchema class
Constructors
- FakeCharacterSchema({required int level, String? weaponSlot, String? runeSlot, String? shieldSlot, String? helmetSlot, String? bodyArmorSlot, String? legArmorSlot, String? bootsSlot, String? ring1Slot, String? ring2Slot, String? amuletSlot, String? artifact1Slot, String? artifact2Slot, String? artifact3Slot, String? utility1Slot, int utility1SlotQuantity = 1, String? utility2Slot, int utility2SlotQuantity = 1})
- Returns a new FakeCharacterSchema instance.
Properties
- amuletSlot ↔ String?
-
Amulet slot item code.
getter/setter pair
- artifact1Slot ↔ String?
-
Artifact 1 slot item code.
getter/setter pair
- artifact2Slot ↔ String?
-
Artifact 2 slot item code.
getter/setter pair
- artifact3Slot ↔ String?
-
Artifact 3 slot item code.
getter/setter pair
- bodyArmorSlot ↔ String?
-
Body armor slot item code.
getter/setter pair
- bootsSlot ↔ String?
-
Boots slot item code.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- helmetSlot ↔ String?
-
Helmet slot item code.
getter/setter pair
- legArmorSlot ↔ String?
-
Leg armor slot item code.
getter/setter pair
- level ↔ int
-
Character level.
getter/setter pair
- ring1Slot ↔ String?
-
Ring 1 slot item code.
getter/setter pair
- ring2Slot ↔ String?
-
Ring 2 slot item code.
getter/setter pair
- runeSlot ↔ String?
-
Rune slot item code.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shieldSlot ↔ String?
-
Shield slot item code.
getter/setter pair
- utility1Slot ↔ String?
-
Utility 1 slot item code.
getter/setter pair
- utility1SlotQuantity ↔ int
-
Utility 1 quantity.
getter/setter pair
- utility2Slot ↔ String?
-
Utility 2 slot item code.
getter/setter pair
- utility2SlotQuantity ↔ int
-
Utility 2 quantity.
getter/setter pair
- weaponSlot ↔ String?
-
Weapon slot item code.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → FakeCharacterSchema? -
Returns a new FakeCharacterSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< FakeCharacterSchema> -
mapFromJson(
dynamic json) → Map< String, FakeCharacterSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< FakeCharacterSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.