askGameAssistantGameAssistantAskPost method
Future<AssistantAnswerSchema?>
askGameAssistantGameAssistantAskPost(
- AssistantQuestionSchema assistantQuestionSchema, {
- Future<
void> ? abortTrigger,
Ask Game Assistant
Ask the game assistant a question about game mechanics or public API usage. An active membership is required. Members receive a limited number of free questions per day. When no free question is available, the request can spend 1 gem with pay_with_gems=true.
Parameters:
- AssistantQuestionSchema assistantQuestionSchema (required):
Implementation
Future<AssistantAnswerSchema?> askGameAssistantGameAssistantAskPost(
AssistantQuestionSchema assistantQuestionSchema, {
Future<void>? abortTrigger,
}) async {
final response = await askGameAssistantGameAssistantAskPostWithHttpInfo(
assistantQuestionSchema,
abortTrigger: abortTrigger,
);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty &&
response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(
await _decodeBodyBytes(response),
'AssistantAnswerSchema',
) as AssistantAnswerSchema;
}
return null;
}