GeOrderHistorySchema class
Constructors
- GeOrderHistorySchema({required String orderId, required String seller, required String buyer, required String code, required int quantity, required int price, required DateTime soldAt})
- Returns a new GeOrderHistorySchema instance.
Properties
- buyer ↔ String
-
Buyer account name.
getter/setter pair
- code ↔ String
-
Item code.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- orderId ↔ String
-
Order id.
getter/setter pair
- price ↔ int
-
Item price per unit.
getter/setter pair
- quantity ↔ int
-
Item quantity.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seller ↔ String
-
Seller account name.
getter/setter pair
- soldAt ↔ DateTime
-
Sale datetime.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → GeOrderHistorySchema? -
Returns a new GeOrderHistorySchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< GeOrderHistorySchema> -
mapFromJson(
dynamic json) → Map< String, GeOrderHistorySchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< GeOrderHistorySchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.