GemShopCustomDesignCatalogItemSchema class
Constructors
- GemShopCustomDesignCatalogItemSchema({required String code, required String name, required String description, required int price, required GemShopCustomDesignCatalogItemSchemaCategoryEnum category, required bool uniqueToAccount})
- Returns a new GemShopCustomDesignCatalogItemSchema instance.
Properties
- category ↔ GemShopCustomDesignCatalogItemSchemaCategoryEnum
-
Custom design category.
getter/setter pair
- code ↔ String
-
Custom design code.
getter/setter pair
- description ↔ String
-
Custom design description.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- name ↔ String
-
Custom design name.
getter/setter pair
- price ↔ int
-
Custom design price in gems.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uniqueToAccount ↔ bool
-
Whether the resulting content is unique to the buyer.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → GemShopCustomDesignCatalogItemSchema? -
Returns a new GemShopCustomDesignCatalogItemSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< GemShopCustomDesignCatalogItemSchema> -
mapFromJson(
dynamic json) → Map< String, GemShopCustomDesignCatalogItemSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< GemShopCustomDesignCatalogItemSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.