GrandExchangeApi class

Constructors

GrandExchangeApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getGeSellHistoryGrandexchangeHistoryCodeGet(String code, {String? seller, String? buyer, int? page, int? size}) Future<DataPageGeOrderHistorySchema?>
Get Ge Sell History
getGeSellHistoryGrandexchangeHistoryCodeGetWithHttpInfo(String code, {String? seller, String? buyer, int? page, int? size}) Future<Response>
Get Ge Sell History
getGeSellOrderGrandexchangeOrdersIdGet(String id) Future<GEOrderReponseSchema?>
Get Ge Sell Order
getGeSellOrderGrandexchangeOrdersIdGetWithHttpInfo(String id) Future<Response>
Get Ge Sell Order
getGeSellOrdersGrandexchangeOrdersGet({String? code, String? seller, int? page, int? size}) Future<DataPageGEOrderSchema?>
Get Ge Sell Orders
getGeSellOrdersGrandexchangeOrdersGetWithHttpInfo({String? code, String? seller, int? page, int? size}) Future<Response>
Get Ge Sell Orders
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited