LogType class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) LogType?
listFromJson(dynamic json, {bool growable = false}) List<LogType>

Constants

achievement → const LogType
buyBankExpansion → const LogType
buyGe → const LogType
cancelGe → const LogType
crafting → const LogType
deleteItem → const LogType
deposit → const LogType
depositGold → const LogType
equip → const LogType
fight → const LogType
gathering → const LogType
movement → const LogType
newTask → const LogType
recycling → const LogType
rest → const LogType
sellGe → const LogType
spawn → const LogType
taskCancelled → const LogType
taskCompleted → const LogType
taskExchange → const LogType
taskTrade → const LogType
unequip → const LogType
use → const LogType
values → const List<LogType>
List of all possible values in this LogType.
withdraw → const LogType
withdrawGold → const LogType