MapSchema class
Constructors
- MapSchema({required int mapId, required String name, required String skin, required int x, required int y, required MapLayer layer, required AccessSchema access, required InteractionSchema interactions})
- Returns a new MapSchema instance.
Properties
- access ↔ AccessSchema
-
Access information for the map
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- interactions ↔ InteractionSchema
-
Interactions available on this map.
getter/setter pair
- layer ↔ MapLayer
-
Layer of the map.
getter/setter pair
- mapId ↔ int
-
ID of the map.
getter/setter pair
- name ↔ String
-
Name of the map.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skin ↔ String
-
Skin of the map.
getter/setter pair
- x ↔ int
-
Position X of the map.
getter/setter pair
- y ↔ int
-
Position Y of the map.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → MapSchema? -
Returns a new MapSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< MapSchema> -
mapFromJson(
dynamic json) → Map< String, MapSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< MapSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.