MapsApi class

Constructors

MapsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllMapsMapsGet({MapLayer? layer, MapContentType? contentType, String? contentCode, bool? hideBlockedMaps, bool? hideEvent, bool? transition, int? page, int? size, Future<void>? abortTrigger}) Future<StaticDataPageMapSchema?>
Get All Maps
getAllMapsMapsGetWithHttpInfo({MapLayer? layer, MapContentType? contentType, String? contentCode, bool? hideBlockedMaps, bool? hideEvent, bool? transition, int? page, int? size, Future<void>? abortTrigger}) Future<Response>
Get All Maps
getLayerMapsMapsLayerGet(MapLayer layer, {MapContentType? contentType, String? contentCode, bool? hideBlockedMaps, bool? hideEvent, bool? transition, int? page, int? size, Future<void>? abortTrigger}) Future<StaticDataPageMapSchema?>
Get Layer Maps
getLayerMapsMapsLayerGetWithHttpInfo(MapLayer layer, {MapContentType? contentType, String? contentCode, bool? hideBlockedMaps, bool? hideEvent, bool? transition, int? page, int? size, Future<void>? abortTrigger}) Future<Response>
Get Layer Maps
getMapByIdMapsIdMapIdGet(int mapId, {Future<void>? abortTrigger}) Future<MapResponseSchema?>
Get Map By Id
getMapByIdMapsIdMapIdGetWithHttpInfo(int mapId, {Future<void>? abortTrigger}) Future<Response>
Get Map By Id
getMapByPositionMapsLayerXYGet(MapLayer layer, int x, int y, {Future<void>? abortTrigger}) Future<MapResponseSchema?>
Get Map By Position
getMapByPositionMapsLayerXYGetWithHttpInfo(MapLayer layer, int x, int y, {Future<void>? abortTrigger}) Future<Response>
Get Map By Position
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited