getMapByPositionMapsLayerXYGet method
Get Map By Position
Retrieve the details of a map by layer and coordinates.
Parameters:
Implementation
Future<MapResponseSchema?> getMapByPositionMapsLayerXYGet(
MapLayer layer,
int x,
int y,
) async {
final response = await getMapByPositionMapsLayerXYGetWithHttpInfo(
layer,
x,
y,
);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty &&
response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(
await _decodeBodyBytes(response),
'MapResponseSchema',
) as MapResponseSchema;
}
return null;
}