getPendingItemsMyPendingItemsGet method
Get Pending Items
Retrieve all unclaimed pending items for your account. These are items from various sources (achievements, grand exchange, events, etc.) that can be claimed by any character on your account using /my/{name}/action/claim/{id}.
Parameters:
Implementation
Future<DataPagePendingItemSchema?> getPendingItemsMyPendingItemsGet({
int? page,
int? size,
}) async {
final response = await getPendingItemsMyPendingItemsGetWithHttpInfo(
page: page,
size: size,
);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty &&
response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(
await _decodeBodyBytes(response),
'DataPagePendingItemSchema',
) as DataPagePendingItemSchema;
}
return null;
}