MyAccountDetails class

Constructors

MyAccountDetails({required String username, required String email, required bool subscribed, required AccountStatus status, List<Object>? badges = const [], required int gems, required int achievementsPoints, required bool banned, String? banReason})
Returns a new MyAccountDetails instance.

Properties

achievementsPoints int
Achievement points.
getter/setter pair
badges List<Object>?
getter/setter pair
banned bool
Banned.
getter/setter pair
banReason String?
Ban reason.
getter/setter pair
email String
Email.
getter/setter pair
gems int
Gems.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status AccountStatus
Member status.
getter/setter pair
subscribed bool
Subscribed for the current season.
getter/setter pair
username String
Username.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) MyAccountDetails?
Returns a new MyAccountDetails instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<MyAccountDetails>
mapFromJson(dynamic json) Map<String, MyAccountDetails>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<MyAccountDetails>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.