MyCharactersApi class

Constructors

MyCharactersApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

actionAcceptNewTaskMyNameActionTaskNewPost(String name) Future<TaskResponseSchema?>
Action Accept New Task
actionAcceptNewTaskMyNameActionTaskNewPostWithHttpInfo(String name) Future<Response>
Action Accept New Task
actionBuyBankExpansionMyNameActionBankBuyExpansionPost(String name) Future<BankExtensionTransactionResponseSchema?>
Action Buy Bank Expansion
actionBuyBankExpansionMyNameActionBankBuyExpansionPostWithHttpInfo(String name) Future<Response>
Action Buy Bank Expansion
actionCompleteTaskMyNameActionTaskCompletePost(String name) Future<TasksRewardDataResponseSchema?>
Action Complete Task
actionCompleteTaskMyNameActionTaskCompletePostWithHttpInfo(String name) Future<Response>
Action Complete Task
actionCraftingMyNameActionCraftingPost(String name, CraftingSchema craftingSchema) Future<SkillResponseSchema?>
Action Crafting
actionCraftingMyNameActionCraftingPostWithHttpInfo(String name, CraftingSchema craftingSchema) Future<Response>
Action Crafting
actionDeleteItemMyNameActionDeletePost(String name, SimpleItemSchema simpleItemSchema) Future<DeleteItemResponseSchema?>
Action Delete Item
actionDeleteItemMyNameActionDeletePostWithHttpInfo(String name, SimpleItemSchema simpleItemSchema) Future<Response>
Action Delete Item
actionDepositBankGoldMyNameActionBankDepositGoldPost(String name, DepositWithdrawGoldSchema depositWithdrawGoldSchema) Future<BankGoldTransactionResponseSchema?>
Action Deposit Bank Gold
actionDepositBankGoldMyNameActionBankDepositGoldPostWithHttpInfo(String name, DepositWithdrawGoldSchema depositWithdrawGoldSchema) Future<Response>
Action Deposit Bank Gold
actionDepositBankMyNameActionBankDepositPost(String name, SimpleItemSchema simpleItemSchema) Future<BankItemTransactionResponseSchema?>
Action Deposit Bank
actionDepositBankMyNameActionBankDepositPostWithHttpInfo(String name, SimpleItemSchema simpleItemSchema) Future<Response>
Action Deposit Bank
actionEquipItemMyNameActionEquipPost(String name, EquipSchema equipSchema) Future<EquipmentResponseSchema?>
Action Equip Item
actionEquipItemMyNameActionEquipPostWithHttpInfo(String name, EquipSchema equipSchema) Future<Response>
Action Equip Item
actionFightMyNameActionFightPost(String name) Future<CharacterFightResponseSchema?>
Action Fight
actionFightMyNameActionFightPostWithHttpInfo(String name) Future<Response>
Action Fight
actionGatheringMyNameActionGatheringPost(String name) Future<SkillResponseSchema?>
Action Gathering
actionGatheringMyNameActionGatheringPostWithHttpInfo(String name) Future<Response>
Action Gathering
actionGeBuyItemMyNameActionGrandexchangeBuyPost(String name, GEBuyOrderSchema gEBuyOrderSchema) Future<GETransactionResponseSchema?>
Action Ge Buy Item
actionGeBuyItemMyNameActionGrandexchangeBuyPostWithHttpInfo(String name, GEBuyOrderSchema gEBuyOrderSchema) Future<Response>
Action Ge Buy Item
actionGeCancelSellOrderMyNameActionGrandexchangeCancelPost(String name, GECancelOrderSchema gECancelOrderSchema) Future<GETransactionResponseSchema?>
Action Ge Cancel Sell Order
actionGeCancelSellOrderMyNameActionGrandexchangeCancelPostWithHttpInfo(String name, GECancelOrderSchema gECancelOrderSchema) Future<Response>
Action Ge Cancel Sell Order
actionGeCreateSellOrderMyNameActionGrandexchangeSellPost(String name, GEOrderCreationrSchema gEOrderCreationrSchema) Future<GECreateOrderTransactionResponseSchema?>
Action Ge Create Sell Order
actionGeCreateSellOrderMyNameActionGrandexchangeSellPostWithHttpInfo(String name, GEOrderCreationrSchema gEOrderCreationrSchema) Future<Response>
Action Ge Create Sell Order
actionMoveMyNameActionMovePost(String name, DestinationSchema destinationSchema) Future<CharacterMovementResponseSchema?>
Action Move
actionMoveMyNameActionMovePostWithHttpInfo(String name, DestinationSchema destinationSchema) Future<Response>
Action Move
actionRecyclingMyNameActionRecyclingPost(String name, RecyclingSchema recyclingSchema) Future<RecyclingResponseSchema?>
Action Recycling
actionRecyclingMyNameActionRecyclingPostWithHttpInfo(String name, RecyclingSchema recyclingSchema) Future<Response>
Action Recycling
actionRestMyNameActionRestPost(String name) Future<CharacterRestResponseSchema?>
Action Rest
actionRestMyNameActionRestPostWithHttpInfo(String name) Future<Response>
Action Rest
actionTaskCancelMyNameActionTaskCancelPost(String name) Future<TaskCancelledResponseSchema?>
Action Task Cancel
actionTaskCancelMyNameActionTaskCancelPostWithHttpInfo(String name) Future<Response>
Action Task Cancel
actionTaskExchangeMyNameActionTaskExchangePost(String name) Future<TasksRewardDataResponseSchema?>
Action Task Exchange
actionTaskExchangeMyNameActionTaskExchangePostWithHttpInfo(String name) Future<Response>
Action Task Exchange
actionTaskTradeMyNameActionTaskTradePost(String name, SimpleItemSchema simpleItemSchema) Future<TaskTradeResponseSchema?>
Action Task Trade
actionTaskTradeMyNameActionTaskTradePostWithHttpInfo(String name, SimpleItemSchema simpleItemSchema) Future<Response>
Action Task Trade
actionUnequipItemMyNameActionUnequipPost(String name, UnequipSchema unequipSchema) Future<EquipmentResponseSchema?>
Action Unequip Item
actionUnequipItemMyNameActionUnequipPostWithHttpInfo(String name, UnequipSchema unequipSchema) Future<Response>
Action Unequip Item
actionUseItemMyNameActionUsePost(String name, SimpleItemSchema simpleItemSchema) Future<UseItemResponseSchema?>
Action Use Item
actionUseItemMyNameActionUsePostWithHttpInfo(String name, SimpleItemSchema simpleItemSchema) Future<Response>
Action Use Item
actionWithdrawBankGoldMyNameActionBankWithdrawGoldPost(String name, DepositWithdrawGoldSchema depositWithdrawGoldSchema) Future<BankGoldTransactionResponseSchema?>
Action Withdraw Bank Gold
actionWithdrawBankGoldMyNameActionBankWithdrawGoldPostWithHttpInfo(String name, DepositWithdrawGoldSchema depositWithdrawGoldSchema) Future<Response>
Action Withdraw Bank Gold
actionWithdrawBankMyNameActionBankWithdrawPost(String name, SimpleItemSchema simpleItemSchema) Future<BankItemTransactionResponseSchema?>
Action Withdraw Bank
actionWithdrawBankMyNameActionBankWithdrawPostWithHttpInfo(String name, SimpleItemSchema simpleItemSchema) Future<Response>
Action Withdraw Bank
getAllCharactersLogsMyLogsGet({int? page, int? size}) Future<DataPageLogSchema?>
Get All Characters Logs
getAllCharactersLogsMyLogsGetWithHttpInfo({int? page, int? size}) Future<Response>
Get All Characters Logs
getMyCharactersMyCharactersGet() Future<MyCharactersListSchema?>
Get My Characters
getMyCharactersMyCharactersGetWithHttpInfo() Future<Response>
Get My Characters
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited