actionCraftingMyNameActionCraftingPost method
Future<SkillResponseSchema?>
actionCraftingMyNameActionCraftingPost(
- String name,
- CraftingSchema craftingSchema
Action Crafting
Craft an item. The character must be on a map with a workshop.
Parameters:
-
String name (required): Name of your character.
-
CraftingSchema craftingSchema (required):
Implementation
Future<SkillResponseSchema?> actionCraftingMyNameActionCraftingPost(
String name,
CraftingSchema craftingSchema,
) async {
final response = await actionCraftingMyNameActionCraftingPostWithHttpInfo(
name,
craftingSchema,
);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty &&
response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(
await _decodeBodyBytes(response),
'SkillResponseSchema',
) as SkillResponseSchema;
}
return null;
}