actionGeCreateBuyOrderMyNameActionGrandexchangeCreateBuyOrderPostWithHttpInfo method
Future<Response>
actionGeCreateBuyOrderMyNameActionGrandexchangeCreateBuyOrderPostWithHttpInfo(
- String name,
- GEBuyOrderCreationSchema gEBuyOrderCreationSchema
Action Ge Create Buy Order
Create a buy order at the Grand Exchange on the character's map. The total gold (price * quantity) is locked when creating the order. Other players can then sell items to fulfill your order. Items will be delivered to your pending items when the order is filled.
Note: This method returns the HTTP Response.
Parameters:
-
String name (required): Name of your character.
-
GEBuyOrderCreationSchema gEBuyOrderCreationSchema (required):
Implementation
Future<Response>
actionGeCreateBuyOrderMyNameActionGrandexchangeCreateBuyOrderPostWithHttpInfo(
String name,
GEBuyOrderCreationSchema gEBuyOrderCreationSchema,
) async {
// ignore: prefer_const_declarations
final path = r'/my/{name}/action/grandexchange/create-buy-order'
.replaceAll('{name}', name);
// ignore: prefer_final_locals
Object? postBody = gEBuyOrderCreationSchema;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
const contentTypes = <String>['application/json'];
return apiClient.invokeAPI(
path,
'POST',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes.first,
);
}