actionGeFillMyNameActionGrandexchangeFillPostWithHttpInfo method
Future<Response>
actionGeFillMyNameActionGrandexchangeFillPostWithHttpInfo(
- String name,
- GEFillBuyOrderSchema gEFillBuyOrderSchema
Action Ge Fill
Sell items to an existing buy order at the Grand Exchange on the character's map. You will receive the gold immediately. The buyer will receive the items in their pending items.
Note: This method returns the HTTP Response.
Parameters:
-
String name (required): Name of your character.
-
GEFillBuyOrderSchema gEFillBuyOrderSchema (required):
Implementation
Future<Response> actionGeFillMyNameActionGrandexchangeFillPostWithHttpInfo(
String name,
GEFillBuyOrderSchema gEFillBuyOrderSchema,
) async {
// ignore: prefer_const_declarations
final path =
r'/my/{name}/action/grandexchange/fill'.replaceAll('{name}', name);
// ignore: prefer_final_locals
Object? postBody = gEFillBuyOrderSchema;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
const contentTypes = <String>['application/json'];
return apiClient.invokeAPI(
path,
'POST',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes.first,
);
}