actionWithdrawBankMyNameActionBankWithdrawPost method

Future<BankItemTransactionResponseSchema?> actionWithdrawBankMyNameActionBankWithdrawPost(
  1. String name,
  2. SimpleItemSchema simpleItemSchema
)

Action Withdraw Bank

Take an item from your bank and put it in the character's inventory.

Parameters:

Implementation

Future<BankItemTransactionResponseSchema?> actionWithdrawBankMyNameActionBankWithdrawPost(String name, SimpleItemSchema simpleItemSchema,) async {
  final response = await actionWithdrawBankMyNameActionBankWithdrawPostWithHttpInfo(name, simpleItemSchema,);
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'BankItemTransactionResponseSchema',) as BankItemTransactionResponseSchema;

  }
  return null;
}