PendingItemSchema class
Constructors
-
PendingItemSchema({required String id, required String account, required PendingItemSource source_, String? sourceId, required String description, int gold = 0, List<
SimpleItemSchema> items = const [], required DateTime createdAt, DateTime? claimedAt}) - Returns a new PendingItemSchema instance.
Properties
- account ↔ String
-
Account username.
getter/setter pair
- claimedAt ↔ DateTime?
-
When the pending item was claimed.
getter/setter pair
- createdAt ↔ DateTime
-
When the pending item was created.
getter/setter pair
- description ↔ String
-
Description for display.
getter/setter pair
- gold ↔ int
-
Gold amount.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- id ↔ String
-
Pending item ID.
getter/setter pair
-
items
↔ List<
SimpleItemSchema> -
List of items to be claimed.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source_ ↔ PendingItemSource
-
Source of the pending item.
getter/setter pair
- sourceId ↔ String?
-
ID reference for the source (e.g., achievement code, order id).
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → PendingItemSchema? -
Returns a new PendingItemSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< PendingItemSchema> -
mapFromJson(
dynamic json) → Map< String, PendingItemSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< PendingItemSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.