RaidSchema class
Constructors
- RaidSchema({required String code, required String name, String? description, required String monster, required RaidScheduleSchema schedule, RaidRewardsSchema? rewards, required RaidStatus status, required DateTime nextStartAt, int participantCount = 0, RaidInstanceSchema? activeInstance, RaidInstanceSchema? latestInstance})
- Returns a new RaidSchema instance.
Properties
- activeInstance ↔ RaidInstanceSchema?
-
Currently active weekly raid instance, if any.
getter/setter pair
- code ↔ String
-
Raid code.
getter/setter pair
- description ↔ String?
-
Raid description.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- latestInstance ↔ RaidInstanceSchema?
-
Latest weekly raid instance, active or finished.
getter/setter pair
- monster ↔ String
-
Monster code used for raid combat simulation.
getter/setter pair
- name ↔ String
-
Raid name.
getter/setter pair
- nextStartAt ↔ DateTime
-
Datetime for the next scheduled raid opening in UTC.
getter/setter pair
- participantCount ↔ int
-
Number of distinct accounts that contributed to the active or latest raid instance.
getter/setter pair
- rewards ↔ RaidRewardsSchema?
-
Reward rules for the raid.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schedule ↔ RaidScheduleSchema
-
Weekly raid opening schedule.
getter/setter pair
- status ↔ RaidStatus
-
Current overall raid status.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → RaidSchema? -
Returns a new RaidSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< RaidSchema> -
mapFromJson(
dynamic json) → Map< String, RaidSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< RaidSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.