getRaidLeaderboardRaidsCodeLeaderboardGet method
Get Raid Leaderboard
Retrieve the leaderboard for the active or latest raid instance.
Parameters:
Implementation
Future<DataPageRaidLeaderboardEntrySchema?>
getRaidLeaderboardRaidsCodeLeaderboardGet(
String code, {
int? page,
int? size,
Future<void>? abortTrigger,
}) async {
final response =
await getRaidLeaderboardRaidsCodeLeaderboardGetWithHttpInfo(
code,
page: page,
size: size,
abortTrigger: abortTrigger,
);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty &&
response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(
await _decodeBodyBytes(response),
'DataPageRaidLeaderboardEntrySchema',
) as DataPageRaidLeaderboardEntrySchema;
}
return null;
}