SeasonSchema class
Constructors
-
SeasonSchema({String? name, int? number, DateTime? startDate, List<
SeasonBadgeSchema> badges = const [], List<SeasonSkinSchema> skins = const []}) - Returns a new SeasonSchema instance.
Properties
-
badges
↔ List<
SeasonBadgeSchema> -
Season badges with required achievement points.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- name ↔ String?
-
Season name.
getter/setter pair
- number ↔ int?
-
Season number.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
skins
↔ List<
SeasonSkinSchema> -
Season skins with required achievement points.
getter/setter pair
- startDate ↔ DateTime?
-
Season start date.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → SeasonSchema? -
Returns a new SeasonSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< SeasonSchema> -
mapFromJson(
dynamic json) → Map< String, SeasonSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< SeasonSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.