StatusSchema class
Constructors
-
StatusSchema({required String version, required DateTime serverTime, required int maxLevel, required int maxSkillLevel, required int charactersOnline, SeasonSchema? season, List<
RateLimitSchema> rateLimits = const []}) - Returns a new StatusSchema instance.
Properties
- charactersOnline ↔ int
-
Characters online.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxLevel ↔ int
-
Maximum level.
getter/setter pair
- maxSkillLevel ↔ int
-
Maximum skill level.
getter/setter pair
-
rateLimits
↔ List<
RateLimitSchema> -
Rate limits.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- season ↔ SeasonSchema?
-
Current season details.
getter/setter pair
- serverTime ↔ DateTime
-
Server time.
getter/setter pair
- version ↔ String
-
Game version.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → StatusSchema? -
Returns a new StatusSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< StatusSchema> -
mapFromJson(
dynamic json) → Map< String, StatusSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< StatusSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.