StatusSeasonRewardSchema class
Constructors
- StatusSeasonRewardSchema({required String code, required RewardType type, required String description, required int requiredPoints, int quantity = 1, bool memberRequired = false, bool firstOnly = false})
- Returns a new StatusSeasonRewardSchema instance.
Properties
- code ↔ String
-
Unique code identifying this reward.
getter/setter pair
- description ↔ String
-
Description of how to earn this reward.
getter/setter pair
- firstOnly ↔ bool
-
Whether this reward is only for the first player to reach the required points.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- memberRequired ↔ bool
-
Whether member status is required to earn this reward.
getter/setter pair
- quantity ↔ int
-
Quantity of the reward (e.g., gold amount, item quantity).
getter/setter pair
- requiredPoints ↔ int
-
Number of achievement points required to earn this reward.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ RewardType
-
Type of the reward.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → StatusSeasonRewardSchema? -
Returns a new StatusSeasonRewardSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< StatusSeasonRewardSchema> -
mapFromJson(
dynamic json) → Map< String, StatusSeasonRewardSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< StatusSeasonRewardSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.