TransitionSchema class
Constructors
-
TransitionSchema({required int mapId, required int x, required int y, required MapLayer layer, List<
ConditionSchema> conditions = const []}) - Returns a new TransitionSchema instance.
Properties
-
conditions
↔ List<
ConditionSchema> -
Conditions for the transition.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- layer ↔ MapLayer
-
Layer of the destination.
getter/setter pair
- mapId ↔ int
-
ID of the destination map.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- x ↔ int
-
Position X of the destination.
getter/setter pair
- y ↔ int
-
Position Y of the destination.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → TransitionSchema? -
Returns a new TransitionSchema instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< TransitionSchema> -
mapFromJson(
dynamic json) → Map< String, TransitionSchema> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< TransitionSchema> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.